@@ -320,7 +320,7 @@ static void dump_vals(int fd, int count, struct VAL *names)
 {
     uint32_t i,j,val32;
     uint16_t val16;
-    off_t val64;
+    loff_t val64;
     char val8;
 
     for (i = 0; names[i].type != EoLST; i++) {
@@ -605,7 +605,7 @@ static boolean ProcessChunk(int fd, off_t filepos, off_t filesize,
 
     case indxtag: {
 	uint32_t chunks=*chunksize-sizeof(names_indx)/sizeof(char*);
-	off_t offset;
+	loff_t offset;
 	uint32_t size, duration;
 	uint32_t u=0;
 	off_t indxend = datapos + chunks;
