@@ -17,15 +17,8 @@
  */
 
 
-/* TODO: 
-
-- Various smaller things -> search for "TODO" and for "QUESTIONS" in
-  the rest of the code
-
-*/
-
-
 #include "transcode.h"
+#include "aclib/ac.h"
 #include "libtc/libtc.h"
 #include "libtc/cfgfile.h"
 #include "libtc/optstr.h"
@@ -33,10 +26,13 @@
 #include "libtc/ratiocodes.h"
 
 #include <x264.h>
+#if X264_BUILD < 65
+# error x264 version 65 or later is required
+#endif
 
 
 #define MOD_NAME    "encode_x264.so"
-#define MOD_VERSION "v0.2.4 (2008-06-14)"
+#define MOD_VERSION "v0.3.2s (2010-01-02)"
 #define MOD_CAP     "x264 encoder"
 
 #define MOD_FEATURES \
@@ -58,17 +54,19 @@ typedef struct {
     int flush_flag;
     x264_param_t x264params;
     x264_t *enc;
+    int twopass_bug_workaround;  // Work around x264 logfile generation bug?
+    char twopass_log_path[4096]; // Logfile path (for 2-pass bug workaround)
 } X264PrivateData;
 
 /* Static structure to provide pointers for configuration entries */
 static struct confdata_struct {
     x264_param_t x264params;
-#if X264_BUILD >= 65
     /* Dummy fields for obsolete options */
+    int dummy_direct_8x8;
     int dummy_bidir_me;
     int dummy_brdo;
-#endif
-    /* No local parameters at the moment */
+    /* Local parameters */
+    int twopass_bug_workaround;
 } confdata;
 
 /*************************************************************************/
@@ -154,15 +152,16 @@ static TCConfigEntry conf[] ={
     /* How many B-frames between 2 reference pictures */
     OPT_RANGE(i_bframe,                   "bframes",        0,    16)
     /* Use adaptive B-frame encoding */
-#if X264_BUILD < 64
-    OPT_FLAG (b_bframe_adaptive,          "b_adapt")
-#else
     OPT_FLAG (i_bframe_adaptive,          "b_adapt")
-#endif
+
     /* How often B-frames are used */
     OPT_RANGE(i_bframe_bias,              "b_bias",       -90,   100)
     /* Keep some B-frames as references */
+#if X264_BUILD >= 78
+    OPT_RANGE(i_bframe_pyramid,           "b_pyramid",      0,     2)
+#else
     OPT_FLAG (b_bframe_pyramid,           "b_pyramid")
+#endif
 
     /* Use deblocking filter */
     OPT_FLAG (b_deblocking_filter,        "deblock")
@@ -176,8 +175,17 @@ static TCConfigEntry conf[] ={
     /* Initial data for CABAC? */
     OPT_RANGE(i_cabac_init_idc,           "cabac_init_idc", 0,     2)
 
+#if X264_BUILD >= 89
+    /* Add NAL HRD parameters to the bitstream */
+    OPT_FLAG (i_nal_hrd,                  "nal_hrd")
+#endif
+
     /* Enable interlaced encoding (--encode_fields) */
     OPT_NONE (b_interlaced)
+#if X264_BUILD >= 89
+    /* First field (1=top, 0=bottom) (--encode_fields) */
+    OPT_NONE (b_tff)
+#endif
 
     /* Quantization matrix selection: 0=flat 1=JVT 2=custom */
     OPT_RANGE(i_cqm_preset,               "cqm",            0,     2)
@@ -203,8 +211,6 @@ static TCConfigEntry conf[] ={
     OPT_FLAG (analyse.b_weighted_bipred,  "weight_b")
     /* Spatial vs temporal MV prediction, 0=none 1=spatial 2=temporal 3=auto */
     OPT_RANGE(analyse.i_direct_mv_pred,   "direct_pred",    0,     3)
-    /* Forbid 4x4 direct partitions (-1 = auto) */
-    OPT_FLAG (analyse.i_direct_8x8_inference, "direct_8x8")
     /* QP difference between chroma and luma */
     OPT_RANGE(analyse.i_chroma_qp_offset, "chroma_qp_offset",-12, 12)
 
@@ -216,17 +222,6 @@ static TCConfigEntry conf[] ={
     OPT_RANGE(analyse.i_mv_range,         "mv_range",      -1,  2048)
     /* Subpixel motion estimation quality: 1=fast, 9=best */
     OPT_RANGE(analyse.i_subpel_refine,    "subq",           1,     9)
-#if X264_BUILD < 65
-    /* Bidirectional motion estimation */
-    OPT_FLAG (analyse.b_bidir_me,         "bidir_me")
-    /* RD based mode decision for B-frames */
-    OPT_FLAG (analyse.b_bframe_rdo,       "brdo")
-#else
-    {"bidir_me",   &confdata.dummy_bidir_me, TCCONF_TYPE_FLAG, 0, 0, 1},
-    {"nobidir_me", &confdata.dummy_bidir_me, TCCONF_TYPE_FLAG, 0, 1, 0},
-    {"brdo",       &confdata.dummy_brdo,     TCCONF_TYPE_FLAG, 0, 0, 1},
-    {"nobrdo",     &confdata.dummy_brdo,     TCCONF_TYPE_FLAG, 0, 1, 0},
-#endif
     /* Chroma ME for subpel and mode decision in P-frames */
     OPT_FLAG (analyse.b_chroma_me,        "chroma_me")
     /* Allow each MB partition in P-frames to have its own reference number */
@@ -272,10 +267,6 @@ static TCConfigEntry conf[] ={
     /* QP ratio between P and B frames */
     OPT_FLOAT(rc.f_pb_factor,             "pb_ratio")
 
-#if X264_BUILD < 64
-    /* Rate control equation for 2-pass encoding (like FFmpeg) */
-    OPT_STR  (rc.psz_rc_eq,               "rc_eq")
-#endif
     /* Complexity blurring before QP compression */
     OPT_RANGF(rc.f_complexity_blur,       "cplx_blur",    0.0, 999.0)
     /* QP curve compression: 0.0 = constant bitrate, 1.0 = constant quality */
@@ -294,6 +285,22 @@ static TCConfigEntry conf[] ={
     OPT_NONE (b_repeat_headers)
     OPT_NONE (i_sps_id)
 
+    /* Module configuration options (which do not affect encoding) */
+
+    {"2pass_bug_workaround", &confdata.twopass_bug_workaround,
+                                                 TCCONF_TYPE_FLAG, 0, 0, 1},
+    {"no2pass_bug_workaround", &confdata.twopass_bug_workaround,
+                                                 TCCONF_TYPE_FLAG, 0, 1, 0},
+
+    /* Obsolete options (scheduled for future removal) */
+
+    {"direct_8x8",   &confdata.dummy_direct_8x8, TCCONF_TYPE_FLAG, 0, 0, 1},
+    {"nodirect_8x8", &confdata.dummy_direct_8x8, TCCONF_TYPE_FLAG, 0, 1, 0},
+    {"bidir_me",     &confdata.dummy_bidir_me,   TCCONF_TYPE_FLAG, 0, 0, 1},
+    {"nobidir_me",   &confdata.dummy_bidir_me,   TCCONF_TYPE_FLAG, 0, 1, 0},
+    {"brdo",         &confdata.dummy_brdo,       TCCONF_TYPE_FLAG, 0, 0, 1},
+    {"nobrdo",       &confdata.dummy_brdo,       TCCONF_TYPE_FLAG, 0, 1, 0},
+
     {NULL}
 };
 
@@ -353,12 +360,11 @@ static void x264_log(void *userdata, int level, const char *format,
  * Parameters:
  *              pass: 0 = single pass
  *                    1 = 1st pass
- *                    2 = 2nd pass
- *                    3 = Nth pass, must also be used for 2nd pass
- *                                  of multipass encoding.
+ *                    2 = 2nd pass (final pass of multipass encoding)
+ *                    3 = Nth pass (intermediate passes of multipass encoding)
  *     statsfilename: where to read and write multipass stat data.
  * Return value:
- *     always 0.
+ *     Always 0.
  * Preconditions:
  *     params != NULL
  *     pass == 0 || statsfilename != NULL
@@ -395,8 +401,8 @@ static int x264params_set_multipass(x264_param_t *params,
 /*************************************************************************/
 
 /**
- * Checks or corrects some strange combinations of settings done in
- * x264params.
+ * x264params_check:  Checks or corrects some strange combinations of
+ * settings done in x264params.
  *
  * Parameters:
  *     params: x264_param_t structure to check
@@ -455,6 +461,9 @@ static int x264params_set_by_vob(x264_param_t *params, const vob_t *vob)
     params->i_height = vob->ex_v_height;
     params->b_interlaced = (vob->encode_fields==TC_ENCODE_FIELDS_TOP_FIRST
                          || vob->encode_fields==TC_ENCODE_FIELDS_BOTTOM_FIRST);
+#if X264_BUILD >= 89
+    params->b_tff        = (vob->encode_fields==TC_ENCODE_FIELDS_TOP_FIRST);
+#endif
 
     if (params->rc.f_rf_constant != 0) {
         params->rc.i_rc_method = X264_RC_CRF;
@@ -494,19 +503,158 @@ static int x264params_set_by_vob(x264_param_t *params, const vob_t *vob)
     /* Set logging function and acceleration flags */
     params->pf_log = x264_log;
     params->p_log_private = NULL;
-    params->cpu = 0;
+    params->cpu &= ~(X264_CPU_MMX
+                   | X264_CPU_MMXEXT
+                   | X264_CPU_SSE
+                   | X264_CPU_SSE2
+                   | X264_CPU_SSE3
+                   | X264_CPU_SSSE3
+                   | X264_CPU_SSE4
+                   | X264_CPU_SSE42
+                   | X264_CPU_LZCNT);
     if (tc_accel & AC_MMX)      params->cpu |= X264_CPU_MMX;
     if (tc_accel & AC_MMXEXT)   params->cpu |= X264_CPU_MMXEXT;
     if (tc_accel & AC_SSE)      params->cpu |= X264_CPU_SSE;
     if (tc_accel & AC_SSE2)     params->cpu |= X264_CPU_SSE2;
-#if X264_BUILD < 60
-    if (tc_accel & AC_3DNOW)    params->cpu |= X264_CPU_3DNOW;
-    if (tc_accel & AC_3DNOWEXT) params->cpu |= X264_CPU_3DNOWEXT;
-#endif
+    if (tc_accel & AC_SSE3)     params->cpu |= X264_CPU_SSE3;
+    if (tc_accel & AC_SSSE3)    params->cpu |= X264_CPU_SSSE3;
+    if (tc_accel & AC_SSE41)    params->cpu |= X264_CPU_SSE4;
+    if (tc_accel & AC_SSE42)    params->cpu |= X264_CPU_SSE42;
+    if (tc_accel & AC_SSE4A)    params->cpu |= X264_CPU_LZCNT;
 
     return TC_OK;
 }
 
+/*************************************************************************/
+
+/**
+ * do_2pass_bug_workaround:  Work around a bug present in at least x264
+ * versions 65 through 67 which causes invalid frame numbers to be written
+ * to the 2-pass logfile.
+ *
+ * Parameters:
+ *     path: Logfile pathname.
+ * Return value:
+ *     0 on success, nonzero otherwise.
+ * Preconditions:
+ *     path != NULL
+ */
+
+static int do_2pass_bug_workaround(const char *path)
+{
+    FILE *fp;
+    char *buffer;
+    long filesize, nread, offset;
+    long nframes;
+
+    fp = fopen(path, "r+");
+    if (!fp) {
+        tc_log_warn(MOD_NAME, "Failed to open 2-pass logfile '%s': %s",
+                    path, strerror(errno));
+        goto error_return;
+    }
+
+    /* x264 treats the logfile as a single, semicolon-separated buffer
+     * rather than a series of lines, so do the same here. */
+
+    /* Read in the logfile data */
+    if (fseek(fp, 0, SEEK_END) != 0) {
+        tc_log_warn(MOD_NAME, "Seek to end of 2-pass logfile failed: %s",
+                    strerror(errno));
+        goto error_close_file;
+    }
+    filesize = ftell(fp);
+    if (filesize < 0) {
+        tc_log_warn(MOD_NAME, "Get size of 2-pass logfile failed: %s",
+                    strerror(errno));
+        goto error_close_file;
+    }
+    buffer = malloc(filesize);
+    if (!buffer) {
+        tc_log_warn(MOD_NAME, "No memory for 2-pass logfile buffer"
+                    " (%ld bytes)", filesize);
+        goto error_close_file;
+    }
+    if (fseek(fp, 0, SEEK_SET) != 0) {
+        tc_log_warn(MOD_NAME, "Seek to beginning of 2-pass logfile failed: %s",
+                    strerror(errno));
+        goto error_free_buffer;
+    }
+    nread = fread(buffer, 1, filesize, fp);
+    if (nread != filesize) {
+        tc_log_warn(MOD_NAME, "Short read on 2-pass logfile (expected %ld"
+                    " bytes, got %ld)", filesize, nread);
+        goto error_free_buffer;
+    }
+
+    /* Count the number of frames */
+    nframes = 0;
+    offset = 0;
+    if (strncmp(buffer, "#options:", 9) == 0) {  // just like x264
+        offset = strcspn(buffer, "\n") + 1;
+    }
+    for (; offset < filesize; offset++) {
+        if (buffer[offset] == ';') {
+            nframes++;
+        }
+    }
+
+    /* Go through the frame list and check for out-of-range frame numbers */
+    offset = 0;
+    if (strncmp(buffer, "#options:", 9) == 0) {
+        offset = strcspn(buffer, "\n") + 1;
+    }
+    while (offset < filesize) {
+        long framenum;
+        char *s;
+        if (strncmp(&buffer[offset], "in:", 3) != 0) {
+            tc_log_warn(MOD_NAME, "Can't parse 2-pass logfile at offset %ld,"
+                        " giving up.", offset);
+            offset = filesize;  // Don't truncate the file
+            break;
+        }
+        framenum = strtol(&buffer[offset+3], &s, 10);
+        if ((s && *s != ' ') || framenum < 0) {
+            tc_log_warn(MOD_NAME, "Can't parse 2-pass logfile at offset %ld,"
+                        " giving up.", offset+3);
+            offset = filesize;  // Don't truncate the file
+            break;
+        }
+        if (framenum >= nframes) {
+            tc_log_warn(MOD_NAME, "Truncating corrupt x264 logfile:");
+            tc_log_warn(MOD_NAME, "    in(%ld) >= nframes(%ld) at offset %ld",
+                        framenum, nframes, offset);
+            tc_log_warn(MOD_NAME, "Please report this bug to the x264"
+                        " developers.");
+            break;  // Truncate the file here
+        }
+        offset += strcspn(&buffer[offset], ";");
+        offset += strspn(&buffer[offset], ";\n");
+    }
+
+    /* Truncate the file if the bug was detected */
+    if (offset < filesize) {
+        if (ftruncate(fileno(fp), offset) != 0) {
+            tc_log_warn(MOD_NAME, "Failed to truncate 2-pass logfile: %s",
+                        strerror(errno));
+            goto error_free_buffer;
+        }
+    }
+
+    /* Successful return */
+    free(buffer);
+    fclose(fp);
+    return 0;
+
+    /* Error handling */
+  error_free_buffer:
+    free(buffer);
+  error_close_file:
+    fclose(fp);
+  error_return:
+    return -1;
+}
+
 /*************************************************************************/
 /*************************************************************************/
 
@@ -595,10 +743,9 @@ static int x264_configure(TCModuleInstance *self,
     confdata.x264params.analyse.inter = ~0;
 
     /* Watch for obsolete options being set */
-#if X264_BUILD >= 65
+    confdata.dummy_direct_8x8 = -1;
     confdata.dummy_bidir_me = -1;
     confdata.dummy_brdo = -1;
-#endif
 
     /* Read settings from configuration file */
     module_read_config(X264_CONFIG_FILE, NULL, conf, MOD_NAME);
@@ -616,7 +763,10 @@ static int x264_configure(TCModuleInstance *self,
     }
 
     /* Complain about obsolete options being set */
-#if X264_BUILD >= 65
+    if (confdata.dummy_direct_8x8 != -1) {
+        tc_log_warn(MOD_NAME, "Option direct_8x8 is obsolete, and is now"
+                    " always active.");
+    }
     if (confdata.dummy_bidir_me != -1) {
         tc_log_warn(MOD_NAME,
                     "Option bidir_me is obsolete in x264 version 65.\n"
@@ -628,14 +778,23 @@ static int x264_configure(TCModuleInstance *self,
                     "Option bidir_me is obsolete in x264 version 65.\n"
                     "    brdo will be automatically applied when subq >= 7.");
     }
-#endif
 
-#if X264_BUILD < 65
-    /* subq values are different in old x264 builds */
-    if (confdata.x264params.analyse.i_subpel_refine > 7) {
-        confdata.x264params.analyse.i_subpel_refine = 7;
+    /* Save multipass logfile name if 2-pass bug workaround was requested */
+    if (confdata.twopass_bug_workaround
+     && (vob->divxmultipass == 1 || vob->divxmultipass == 3)
+    ) {
+        const size_t strsize = strlen(vob->divxlogfile) + 1;
+        if (strsize > sizeof(pd->twopass_log_path)) {
+            tc_log_error(MOD_NAME, "2-pass logfile path too long.\n"
+                         "    Use a shorter pathname or disable the"
+                         " 2pass_bug_workaround option.");
+            return TC_ERROR;
+        }
+        ac_memcpy(pd->twopass_log_path, vob->divxlogfile, strsize);
+        pd->twopass_bug_workaround = 1;
+    } else {
+        pd->twopass_bug_workaround = 0;
     }
-#endif
 
     /* Apply extra settings to $x264params */
     if (0 != x264params_set_multipass(&confdata.x264params, vob->divxmultipass,
@@ -697,6 +856,10 @@ static int x264_stop(TCModuleInstance *self)
         pd->enc = NULL;
     }
 
+    if (pd->twopass_bug_workaround) {
+        do_2pass_bug_workaround(pd->twopass_log_path);
+    }
+
     return TC_OK;
 }
 
@@ -741,12 +904,12 @@ static int x264_inspect(TCModuleInstance *self,
  */
 
 static int x264_encode_video(TCModuleInstance *self,
-                            vframe_list_t *inframe, vframe_list_t *outframe)
+                             vframe_list_t *inframe, vframe_list_t *outframe)
 {
     X264PrivateData *pd;
     x264_nal_t *nal;
     x264_picture_t pic, pic_out;
-    int nnal, i;
+    int nnal, i, ret;
 
     TC_MODULE_SELF_CHECK(self, "encode_video");
 
@@ -754,45 +917,56 @@ static int x264_encode_video(TCModuleInstance *self,
 
     pd->framenum++;
 
+    memset(&pic,     0, sizeof(pic));
+    memset(&pic_out, 0, sizeof(pic_out));
+
     if (inframe == NULL) {
         outframe->video_len = 0;
         return TC_OK;
     }
 
     pic.img.i_csp = X264_CSP_I420;
-    pic.img.i_plane = 3;
+    pic.img.i_plane     = 3;
 
-    pic.img.plane[0] = inframe->video_buf;
+    pic.img.plane[0]    = inframe->video_buf;
     pic.img.i_stride[0] = inframe->v_width;
 
-    pic.img.plane[1] = pic.img.plane[0] + inframe->v_width*inframe->v_height;
+    pic.img.plane[1]    = pic.img.plane[0]
+                          + inframe->v_width*inframe->v_height;
     pic.img.i_stride[1] = inframe->v_width / 2;
 
-    pic.img.plane[2] = pic.img.plane[1]
-                     + (inframe->v_width/2)*(inframe->v_height/2);
+    pic.img.plane[2]    = pic.img.plane[1]
+                          + (inframe->v_width/2)*(inframe->v_height/2);
     pic.img.i_stride[2] = inframe->v_width / 2;
 
 
     pic.i_type = X264_TYPE_AUTO;
     pic.i_qpplus1 = 0;
-    /* QUESTION: Is this pts-handling ok? I don't have a clue how
+    /* FIXME: Is this pts-handling ok? I don't have a clue how
      * PTS/DTS handling works. Does it matter, when no muxing is
      * done? */
     pic.i_pts = (int64_t) pd->framenum * pd->x264params.i_fps_den;
 
-    if (x264_encoder_encode(pd->enc, &nal, &nnal, &pic, &pic_out) != 0) {
+    ret = x264_encoder_encode(pd->enc, &nal, &nnal, &pic, &pic_out);
+#if X264_BUILD >= 76
+    if (ret < 0) {
+#else
+    if (ret != 0) {
+#endif
         return TC_ERROR;
     }
 
     outframe->video_len = 0;
     for (i = 0; i < nnal; i++) {
-        int size, ret;
-
-        size = outframe->video_size - outframe->video_len;
+        int size = outframe->video_size - outframe->video_len;
         if (size <= 0) {
             tc_log_error(MOD_NAME, "output buffer overflow");
             return TC_ERROR;
         }
+#if X264_BUILD >= 76
+        ac_memcpy(outframe->video_buf + outframe->video_len, nal[i].p_payload, nal[i].i_payload); 
+        outframe->video_len += nal[i].i_payload;
+#else
         ret = x264_nal_encode(outframe->video_buf + outframe->video_len,
                               &size, 1, &nal[i]);
         if (ret < 0 || size > outframe->video_size - outframe->video_len) {
@@ -800,6 +974,7 @@ static int x264_encode_video(TCModuleInstance *self,
             break;
         }
         outframe->video_len += size;
+#endif
     }
 
     /* FIXME: ok, that sucks. How to reformat it ina better way? -- fromani */
