@@ -346,7 +346,12 @@ static int tc_audio_init_ffmpeg(vob_t *vob, int o_codec)
 
     //-- set parameters (bitrate, channels and sample-rate) --
     //--------------------------------------------------------
-    memset(&mpa_ctx, 0, sizeof(mpa_ctx));          // default all
+    avcodec_get_context_defaults(&mpa_ctx);
+#if LIBAVCODEC_VERSION_MAJOR < 53
+    mpa_ctx.codec_type  = CODEC_TYPE_AUDIO;
+#else
+    mpa_ctx.codec_type  = AVMEDIA_TYPE_AUDIO;
+#endif
     mpa_ctx.bit_rate    = vob->mp3bitrate * 1000;  // bitrate dest.
     mpa_ctx.channels    = vob->dm_chan;            // channels
     mpa_ctx.sample_rate = vob->a_rate;
@@ -357,7 +362,8 @@ static int tc_audio_init_ffmpeg(vob_t *vob, int o_codec)
     ret = avcodec_open(&mpa_ctx, mpa_codec);
     TC_UNLOCK_LIBAVCODEC;
     if (ret < 0) {
-        tc_warn("tc_audio_init_ffmpeg: could not open mpa codec !");
+        tc_warn("tc_audio_init_ffmpeg: could not open %s codec !",
+                (codeid == CODEC_ID_MP2) ?"mpa" :"ac3");
         return(TC_EXPORT_ERROR);
     }
 
