@@ -1,67 +1,64 @@
 /*
  *  export_divx5.c
  *
- *  Copyright (C) Thomas streich - June 2001
+ *  Copyright (C) Thomas Oestreich - June 2001
  *
  *  2-pass code OpenDivX port: "-R 1", "-R 2"
  *  Copyright (C) 2001 Christoph Lampert <gruel@web.de>
  *
- *  constant quantizer extensions "-R 3" by Gerhard Monzel 
+ *  constant quantizer extensions "-R 3" by Gerhard Monzel
  *  <gerhard.monzel@sap.com>
  *
  *  This module is derived from export_divx4.c, minor modification by
  *  Christoph Lampert <gruel@web.de>
  *
  *  This file is part of transcode, a video stream processing tool
- *      
+ *
  *  transcode is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 2, or (at your option)
  *  any later version.
- *   
+ *
  *  transcode is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
- *   
+ *
  *  You should have received a copy of the GNU General Public License
  *  along with GNU Make; see the file COPYING.  If not, write to
- *  the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA. 
+ *  the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
  *
  */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <sys/stat.h>
 #include <unistd.h>
 #include <fcntl.h>
 #include <math.h>
-
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
-
-#ifdef HAVE_STDINT_H
 #include <stdint.h>
-#endif
 
 #ifdef HAVE_DLFCN_H
 #include <dlfcn.h>
 #else
-# ifdef SYSTEM_DARWIN
+# ifdef OS_DARWIN
 #  include "libdldarwin/dlfcn.h"
 # endif
 #endif
 
 
 
-#ifdef HAVE_DIVX_ENCORE2
+#ifdef HAVE_ENCORE2_H
 #include <encore2.h>
 #else
 #include "divx5_encore2.h"
 #endif
 #include "transcode.h"
-#include "avilib.h"
+#include "avilib/avilib.h"
 #include "aud_aux.h"
 #include "vbr.h"
 
@@ -79,7 +76,7 @@ int VbrMode=0;
 int force_key_frame=-1;
 
 static avi_t *avifile=NULL;
-  
+
 //temporary audio/video buffer
 static char *buffer;
 
@@ -116,63 +113,60 @@ static char * prof2name(int n)
 
 #define MODULE "libdivxencore.so.0"
 
-static int divx5_init(char *path) {
-#ifdef SYS_BSD /* Just in case ProjectMayo will release FreeBSD library :-) */  
-  const
-#endif  
-  char *error;
+static int divx5_init(const char *path) {
+  const char *error;
   int *quiet_encore;
-  
-  snprintf(module, sizeof(module), "%s/%s", path, MODULE);
-  
+
+  tc_snprintf(module, sizeof(module), "%s/%s", path, MODULE);
+
 
   // try transcode's module directory
-  
-  handle = dlopen(module, RTLD_NOW); 
-  
+
+  handle = dlopen(module, RTLD_NOW);
+
   if (!handle) {
-    
+
     //try the default:
-    
+
     handle = dlopen(MODULE, RTLD_GLOBAL| RTLD_LAZY);
-    
+
     if (!handle) {
-      fprintf(stderr, "[%s] %s\n", MOD_NAME, dlerror());
+      tc_log_warn(MOD_NAME, "%s", dlerror());
       return(-1);
-    } else {  
-      if(verbose_flag & TC_DEBUG) 
-        fprintf(stderr, "[%s] Loading external codec module %s\n", MOD_NAME, MODULE);
+    } else {
+      if(verbose_flag & TC_DEBUG)
+        tc_log_info(MOD_NAME, "Loading external codec module %s", MODULE);
     }
-    
-  } else {  
-    if(verbose_flag & TC_DEBUG) 
-      fprintf(stderr, "[%s] Loading external codec module %s\n", MOD_NAME, module);
+
+  } else {
+    if(verbose_flag & TC_DEBUG)
+      tc_log_info(MOD_NAME, "Loading external codec module %s", module);
   }
-  
-  divx5_encore = dlsym(handle, "encore");   
-  
+
+  divx5_encore = dlsym(handle, "encore");
+
   if ((error = dlerror()) != NULL)  {
-    fprintf(stderr, "[%s] %s\n", MOD_NAME, error);
+    tc_log_warn(MOD_NAME, "%s", error);
     return(-1);
   }
-  
-  quiet_encore=dlsym(handle, "quiet_encore"); 
-  
+
+  quiet_encore=dlsym(handle, "quiet_encore");
+
   if ((error = dlerror()) != NULL)  {
-    fprintf(stderr, "[%s] %s\n", MOD_NAME, error);
+    tc_log_warn(MOD_NAME, "%s", error);
     return(-1);
   }
-  
+
   *quiet_encore=1;
-  
+
   // debug
-  if(verbose_flag & TC_STATS) *quiet_encore=0; 
-  
+  if(verbose_flag & TC_STATS) *quiet_encore=0;
+
   return(0);
 }
 
 
-/* ------------------------------------------------------------ 
+/* ------------------------------------------------------------
  *
  * init codec
  *
@@ -187,71 +181,71 @@ MOD_init
 #endif
   int ch;
 
-	fprintf(stderr, "[%s] *** Warning: DivX is broken and support for it is ***\n", MOD_NAME);
-	fprintf(stderr, "[%s] *** obsolete in transcode. Sooner or later it  ***\n", MOD_NAME);
-	fprintf(stderr, "[%s] *** will be removed from transcode. Don't use ***\n", MOD_NAME);
-	fprintf(stderr, "[%s] *** DivX. Use xvid or ffmpeg -F mpeg4 instead ***\n", MOD_NAME);
-	fprintf(stderr, "[%s] *** for all your mpeg4 encodings. ***\n", MOD_NAME);
-  
+  	tc_log_warn(MOD_NAME, "*** Warning: DivX is broken and support for it is ***");
+	tc_log_warn(MOD_NAME, "*** obsolete in transcode. Sooner or later it  ***");
+	tc_log_warn(MOD_NAME, "*** will be removed from transcode. Don't use ***");
+	tc_log_warn(MOD_NAME, "*** DivX. Use xvid or ffmpeg -F mpeg4 instead ***");
+	tc_log_warn(MOD_NAME, "*** for all your mpeg4 encodings. ***");
+
   if(param->flag == TC_VIDEO) {
 
     //check for odd frame parameter:
 
     if((ch = vob->ex_v_width - ((vob->ex_v_width>>3)<<3)) != 0) {
-      printf("[%s] frame width %d (no multiple of 8)\n", MOD_NAME, vob->ex_v_width);
-      printf("[%s] encoder may not work correctly or crash\n", MOD_NAME);
-      
+      tc_log_warn(MOD_NAME, "frame width %d (no multiple of 8)", vob->ex_v_width);
+      tc_log_warn(MOD_NAME, "encoder may not work correctly or crash");
+
       if(ch & 1) {
-	printf("[%s] invalid frame width\n", MOD_NAME); 
-	return(TC_EXPORT_ERROR); 
+	tc_log_warn(MOD_NAME, "invalid frame width");
+	return(TC_EXPORT_ERROR);
       }
     }
-   
+
     if((ch = vob->ex_v_height - ((vob->ex_v_height>>3)<<3)) != 0) {
-      printf("[%s] frame height %d (no multiple of 8)\n", MOD_NAME, vob->ex_v_height);
-      printf("[%s] encoder may not work correctly or crash\n", MOD_NAME);
-     
+      tc_log_warn(MOD_NAME, "frame height %d (no multiple of 8)", vob->ex_v_height);
+      tc_log_warn(MOD_NAME, "encoder may not work correctly or crash");
+
       if(ch & 1) {
-	printf("[%s] invalid frame height\n", MOD_NAME); 
-	return(TC_EXPORT_ERROR); 
+	tc_log_warn(MOD_NAME, "invalid frame height");
+	return(TC_EXPORT_ERROR);
       }
     }
-    
+
     if ((buffer = malloc(vob->ex_v_height*vob->ex_v_width*3))==NULL) {
-      perror("out of memory");
-      return(TC_EXPORT_ERROR); 
+      tc_log_perror(MOD_NAME, "out of memory");
+      return(TC_EXPORT_ERROR);
     } else
-      
-    memset(buffer, 0, vob->ex_v_height*vob->ex_v_width*3);  	
+
+    memset(buffer, 0, vob->ex_v_height*vob->ex_v_width*3);
 
     //load the codec
 
     if(divx5_init(vob->mod_path)<0) {
-      tc_warn("failed to init DivX 5.0 Codec");
-      return(TC_EXPORT_ERROR); 
+      tc_log_warn(MOD_NAME, "failed to init DivX 5.0 Codec");
+      return(TC_EXPORT_ERROR);
     }
 
     if (divx5_encore(0, ENC_OPT_VERSION, 0, 0) != ENCORE_VERSION) {
-	tc_warn("API in encore.h is not compatible with installed lbdivxencore library");
+	tc_log_warn(MOD_NAME, "API in encore.h is not compatible with installed lbdivxencore library");
 	return (TC_EXPORT_ERROR);
     }
 
     VbrMode = vob->divxmultipass;
-    // 0 for nothing,  
-    // 1 for DivX 5.0 - first-pass, 
+    // 0 for nothing,
+    // 1 for DivX 5.0 - first-pass,
     // 2 for DivX 5.0 - second pass
     // 3 constant quantizer
-    
+
 #if ENCORE_VERSION >= 20021024
 #define FOURCC(A, B, C, D) ( ((uint8_t) (A)) | (((uint8_t) (B))<<8) | (((uint8_t) (C))<<16) | (((uint8_t) (D))<<24) )
 
     if ((settings = malloc(sizeof(SETTINGS)))==NULL) {
-      perror("out of memory");
-      return(TC_EXPORT_ERROR); 
+      tc_log_perror(MOD_NAME, "out of memory");
+      return(TC_EXPORT_ERROR);
     }
     if ((format = malloc(sizeof(DivXBitmapInfoHeader)))==NULL) {
-      perror("out of memory");
-      return(TC_EXPORT_ERROR); 
+      tc_log_perror(MOD_NAME, "out of memory");
+      return(TC_EXPORT_ERROR);
     }
     memset (settings, 0, sizeof(SETTINGS));
     memset (format, 0, sizeof(DivXBitmapInfoHeader));
@@ -292,10 +286,10 @@ MOD_init
 
     if (vob->divxlogfile && *vob->divxlogfile) {
 	if ((logfile_mv = malloc (strlen(vob->divxlogfile)+4)) == NULL) {
-            fprintf(stderr, "Cannot allocate memory for logfile_mv\n");
+            tc_log_error(MOD_NAME, "Cannot allocate memory for logfile_mv");
             return(TC_EXPORT_ERROR);
         }
-	snprintf(logfile_mv, strlen(vob->divxlogfile)+4, "%s_mv", vob->divxlogfile);
+	tc_snprintf(logfile_mv, strlen(vob->divxlogfile)+4, "%s_mv", vob->divxlogfile);
     }
 
     // default -- expose this to user?
@@ -307,7 +301,7 @@ MOD_init
     settings->quality = vob->divxquality;
 
     if (VbrMode == 1 || VbrMode == 2){
-	 /* 
+	 /*
 	  * http://www.divx.com/support/divx/guide_mac.php
 	  *
 	  * Handheld 128000,262144,196608
@@ -345,7 +339,8 @@ MOD_init
 		 break;
 	 }
 	 if (verbose & TC_DEBUG)
-	     printf("[%s] Using VBV Profile [%d] (%s)\n", MOD_NAME, vob->divx5_vbv_prof, 
+	     tc_log_info(MOD_NAME, "Using VBV Profile [%d] (%s)",
+		     vob->divx5_vbv_prof,
 		     prof2name(vob->divx5_vbv_prof));
 
     }
@@ -385,21 +380,21 @@ MOD_init
     settings->enable_resize = 0;
 
     if(divx5_encore(&encore_handle, ENC_OPT_INIT, format, settings) < 0) {
-      tc_warn("Error doing ENC_OPT_INIT");
-      return(TC_EXPORT_ERROR); 
+      tc_log_warn(MOD_NAME, "Error doing ENC_OPT_INIT");
+      return(TC_EXPORT_ERROR);
     }
 
 #else
 
     if ((divx = malloc(sizeof(ENC_PARAM)))==NULL) {
-	perror("out of memory");
-      return(TC_EXPORT_ERROR); 
+	tc_log_perror(MOD_NAME, "out of memory");
+      return(TC_EXPORT_ERROR);
     }
 
     memset(divx, 0, sizeof(ENC_PARAM));
 
     //important parameter (Note: use_bidirect and obmc have been removed since DivX4)
-    
+
     divx->x_dim     = vob->ex_v_width;
     divx->y_dim     = vob->ex_v_height;
     divx->framerate = vob->ex_fps;
@@ -410,7 +405,7 @@ MOD_init
     divx->min_quantizer      = vob->min_quantizer;
     divx->max_quantizer      = vob->max_quantizer;
     divx->rc_period          = vob->rc_period;
-    divx->rc_reaction_period = vob->rc_reaction_period; 
+    divx->rc_reaction_period = vob->rc_reaction_period;
     divx->rc_reaction_ratio  = vob->rc_reaction_ratio;
 
     divx->max_key_interval   = vob->divxkeyframes;
@@ -420,94 +415,98 @@ MOD_init
     divx->handle=NULL;
 
     if(divx5_encore(NULL, ENC_OPT_INIT, divx, NULL) < 0) {
-      tc_warn("DivX codec init error");
-      return(TC_EXPORT_ERROR); 
+      tc_log_warn(MOD_NAME, "DivX codec init error");
+      return(TC_EXPORT_ERROR);
     }
 
     // catch API mismatch
     if(!divx || !divx->handle) {
-      tc_warn("DivX codec open error");
-      return(TC_EXPORT_ERROR); 
+      tc_log_warn(MOD_NAME, "DivX codec open error");
+      return(TC_EXPORT_ERROR);
     }
-    
-    if(verbose_flag & TC_DEBUG) 
+
+    if(verbose_flag & TC_DEBUG)
       {
-       //-- GMO start -- 
-        if (vob->divxmultipass == 3) { 
-          fprintf(stderr, "[%s]    single-pass session: %d (VBR)\n", MOD_NAME, vob->divxmultipass);
-          fprintf(stderr, "[%s]          VBR-quantizer: %d\n", MOD_NAME, vob->divxbitrate);
+       //-- GMO start --
+       if (vob->divxmultipass == 3) {
+          tc_log_info(MOD_NAME, "    single-pass session: %d (VBR)", vob->divxmultipass);
+          tc_log_info(MOD_NAME, "          VBR-quantizer: %d", vob->divxbitrate);
         } else {
-	  fprintf(stderr, "[%s]     multi-pass session: %d\n", MOD_NAME, vob->divxmultipass);
-	  fprintf(stderr, "[%s]      bitrate [kBits/s]: %d\n", MOD_NAME, divx->bitrate/1000);
+	  tc_log_info(MOD_NAME, "     multi-pass session: %d", vob->divxmultipass);
+	  tc_log_info(MOD_NAME, "      bitrate [kBits/s]: %d", divx->bitrate/1000);
 	}
-	
-	fprintf(stderr, "[%s]                quality: %d\n", MOD_NAME, divx->quality);
+
+	tc_log_info(MOD_NAME, "                quality: %d", divx->quality);
         //-- GMO end --
 
-	fprintf(stderr, "[%s]              crispness: %d\n", MOD_NAME, vob->divxcrispness);
-	fprintf(stderr, "[%s]  max keyframe interval: %d\n", MOD_NAME, divx->max_key_interval);
-	fprintf(stderr, "[%s]             frame rate: %.2f\n", MOD_NAME, vob->ex_fps);
-	fprintf(stderr, "[%s]            color space: %s\n", MOD_NAME, (vob->im_v_codec==CODEC_RGB) ? "RGB24":"YV12");
-	fprintf(stderr, "[%s]            deinterlace: %d\n", MOD_NAME, divx->deinterlace);
+	tc_log_info(MOD_NAME, "              crispness: %d", vob->divxcrispness);
+	tc_log_info(MOD_NAME, "  max keyframe interval: %d", divx->max_key_interval);
+	tc_log_info(MOD_NAME, "             frame rate: %.2f", vob->ex_fps);
+	tc_log_info(MOD_NAME, "            color space: %s", (vob->im_v_codec==CODEC_RGB) ? "RGB24" : "YUV420P");
+	tc_log_info(MOD_NAME, "            deinterlace: %d", divx->deinterlace);
     }
 
-    encode.colorspace = (vob->im_v_codec==CODEC_RGB) ? ENC_CSP_RGB24:ENC_CSP_YV12;
+    encode.colorspace = (vob->im_v_codec==CODEC_RGB) ? ENC_CSP_RGB24:ENC_CSP_I420;
     encode.mvs = NULL;
 
     encode.bitstream = buffer;
 
-    
+
     switch(VbrMode) {
-	
+
     case 1:
-	VbrControl_init_2pass_vbr_analysis(vob->divxlogfile, divx->quality);   
+	VbrControl_init_2pass_vbr_analysis(vob->divxlogfile, divx->quality);
 	break;
-	
+
     case 2:
-      
+
       // check for logfile
-      
+
       if(vob->divxlogfile==NULL || stat(vob->divxlogfile, &fbuf)){
-	fprintf(stderr, "(%s) pass-1 logfile \"%s\" not found exit\n", __FILE__, 
+	tc_log_warn(MOD_NAME, "pass-1 logfile \"%s\" not found exit",
 		vob->divxlogfile);
 	return(TC_EXPORT_ERROR);
     }
 
 
       // second pass: read back the logfile
-      VbrControl_init_2pass_vbr_encoding(vob->divxlogfile, 
-					 divx->bitrate, 
-					 divx->framerate, 
-					 vob->divxcrispness, 
+      VbrControl_init_2pass_vbr_encoding(vob->divxlogfile,
+					 divx->bitrate,
+					 divx->framerate,
+					 vob->divxcrispness,
 					 divx->quality);
       break;
 
-      //-- GMO start --  
+      //-- GMO start --
     case 3:
-	VbrControl_init_2pass_vbr_analysis(vob->divxlogfile, divx->quality);   
+	VbrControl_init_2pass_vbr_analysis(vob->divxlogfile, divx->quality);
 
       encode.quant = vob->divxbitrate;
       encode.intra = -1;
       break;
       //-- GMO end --
- 
+
     default:
       // none
       break;
     }
 #endif
-    
-    return(0);
+
+    return(TC_EXPORT_OK);
   }
-  
-  if(param->flag == TC_AUDIO) return(audio_init(vob, verbose));    
-  
+
+  if(param->flag == TC_AUDIO) {
+	tc_log_warn(MOD_NAME, "Usage of this module for audio encoding is deprecated.");
+	tc_log_warn(MOD_NAME, "Consider switch to export_tcaud module.");
+	return(tc_audio_init(vob, verbose));
+  }
+
   // invalid flag
-  return(TC_EXPORT_ERROR); 
+  return(TC_EXPORT_ERROR);
 }
 
 
-/* ------------------------------------------------------------ 
+/* ------------------------------------------------------------
  *
  * open outputfile
  *
@@ -517,28 +516,28 @@ MOD_open
 {
 
   // open file
-  if(vob->avifile_out==NULL) 
+  if(vob->avifile_out==NULL)
     if(NULL == (vob->avifile_out = AVI_open_output_file(vob->video_out_file))) {
       AVI_print_error("avi open error");
-      return(TC_EXPORT_ERROR); 
+      return(TC_EXPORT_ERROR);
     }
-  
+
   /* save locally */
   avifile = vob->avifile_out;
 
-  if(param->flag == TC_AUDIO) return(audio_open(vob, vob->avifile_out));  
-  
+  if(param->flag == TC_AUDIO) return(tc_audio_open(vob, vob->avifile_out));
+
   if(param->flag == TC_VIDEO) {
-    
+
     // video
 #if ENCORE_MAJOR_VERSION >= 5010
-    AVI_set_video(vob->avifile_out, vob->ex_v_width, vob->ex_v_height, 
+    AVI_set_video(vob->avifile_out, vob->ex_v_width, vob->ex_v_height,
 		  vob->ex_fps, "DX50");
 #else
-    AVI_set_video(vob->avifile_out, vob->ex_v_width, vob->ex_v_height, 
+    AVI_set_video(vob->avifile_out, vob->ex_v_width, vob->ex_v_height,
 		  vob->ex_fps, "DIVX");
 #endif
-    
+
     if (vob->avi_comment_fd>0)
 	AVI_set_comment_fd(vob->avifile_out, vob->avi_comment_fd);
 
@@ -546,16 +545,16 @@ MOD_open
     //first frame will be a key fame anayway. Therefore key.quantizer
     //is well defined for any frame to follow
     force_key_frame=(force_key_frame<0) ? 0:1;
-    
+
     return(0);
   }
-  
+
   // invalid flag
-  return(TC_EXPORT_ERROR); 
+  return(TC_EXPORT_ERROR);
 }
 
 
-/* ------------------------------------------------------------ 
+/* ------------------------------------------------------------
  *
  * encode and export frame
  *
@@ -564,40 +563,34 @@ MOD_open
 
 MOD_encode
 {
-  
-  if(param->flag == TC_VIDEO) { 
-    
+
+  if(param->flag == TC_VIDEO) {
+
     // encode video
-    
+
     encode.image = param->buffer;
     encode.bitstream = buffer;
-    
+
 #if ENCORE_VERSION >= 20021024
     encode.produce_empty_frame = 0;
 
     do {
 	if(divx5_encore(encore_handle, ENC_OPT_ENCODE, &encode, &key) < 0) {
-	    tc_warn("DivX encoder error");
-	    return(TC_EXPORT_ERROR); 
-	}	
+	    tc_log_warn(MOD_NAME, "DivX encoder error");
+	    return(TC_EXPORT_ERROR);
+	}
 	// write bitstream
 	if(key.cType != '\0') {
-	    /*
-	    printf("Quant(%d) Type(%c) Motion(%d) Texture(%d) Stuffing(%d) Total(%d) SeqNr(%d) length(%d)\n",
-		    key.iQuant, key.cType, key.iMotionBits, key.iTextureBits, 
-		    key.iStuffingBits, key.iTotalBits, key.iSequenceNumber, encode.length);
-		    */
-
 	    /* split the AVI */
-	    if((uint32_t)(AVI_bytes_written(avifile)+encode.length+16+8)>>20 >= tc_avi_limit) 
+	    if((uint32_t)(AVI_bytes_written(avifile)+encode.length+16+8)>>20 >= tc_avi_limit)
 		tc_outstream_rotate_request();
 
 	    //0.6.2: switch outfile on "C" and -J pv
 	    if(key.cType == 'I') tc_outstream_rotate();
 
 	    if(AVI_write_frame(avifile, buffer, encode.length, (key.cType == 'I')?1:0)<0) {
-		tc_warn("DivX avi video write error");
-		return(TC_EXPORT_ERROR); 
+		tc_log_warn(MOD_NAME, "DivX avi video write error");
+		return(TC_EXPORT_ERROR);
 	    }
 	}
 	encode.image = NULL;
@@ -605,9 +598,9 @@ MOD_encode
 #else
     switch(VbrMode) {
 
-   //-- GMO start --   
+   //-- GMO start --
     case 3:
-    
+
       if (force_key_frame)
       {
         encode.intra    = 1;
@@ -615,72 +608,72 @@ MOD_encode
       }
       else
         encode.intra = -1;
-          
-      if(divx5_encore(divx->handle, ENC_OPT_ENCODE_VBR, &encode, &key) < 0) 
+
+      if(divx5_encore(divx->handle, ENC_OPT_ENCODE_VBR, &encode, &key) < 0)
       {
-	printf("encoder error");
-	return(TC_EXPORT_ERROR); 
+	tc_log_warn(MOD_NAME, "encoder error");
+	return(TC_EXPORT_ERROR);
       }
 
 
-      VbrControl_update_2pass_vbr_analysis(key.is_key_frame, 
-					       key.motion_bits, 
-					       key.texture_bits, 
-					       key.total_bits, 
+      VbrControl_update_2pass_vbr_analysis(key.is_key_frame,
+					       key.motion_bits,
+					       key.texture_bits,
+					       key.total_bits,
 					       key.quantizer);
       break;
     //-- GMO end --
- 	
+
     case 2:
 	// second pass of 2-pass, just a hack for the moment
 
-	encode.quant = VbrControl_get_quant();		
+	encode.quant = VbrControl_get_quant();
 	encode.intra = VbrControl_get_intra();
 
 	if(force_key_frame) {
 	    encode.intra=1;    //key frame
 	    force_key_frame=0; //reset
 	}
-	
+
       if(divx5_encore(divx->handle, ENC_OPT_ENCODE_VBR, &encode, &key) < 0) {
-	printf("encoder error");
-	return(TC_EXPORT_ERROR); 
+	tc_log_warn(MOD_NAME, "encoder error");
+	return(TC_EXPORT_ERROR);
       }
-      
-      VbrControl_update_2pass_vbr_encoding(key.motion_bits, 
-					   key.texture_bits, 
+
+      VbrControl_update_2pass_vbr_encoding(key.motion_bits,
+					   key.texture_bits,
 					   key.total_bits);
       break;
 
     default:
-      
+
       if(force_key_frame) {
-	
+
 	encode.intra=1; //key frame
 	encode.quant=key.quantizer; //well defined for frames != first frame.
-	
+
 	if(divx5_encore(divx->handle, ENC_OPT_ENCODE_VBR, &encode, &key) < 0) {
-	  printf("encoder error");
-	  return(TC_EXPORT_ERROR); 
+	  tc_log_warn(MOD_NAME, "encoder error");
+	  return(TC_EXPORT_ERROR);
 	}
-	
+
 	//reset
-	force_key_frame=0; 
+	force_key_frame=0;
 
       } else {
-	  
+
 	  if(divx5_encore(divx->handle, ENC_OPT_ENCODE, &encode, &key) < 0) {
-	      printf("encoder error");
-	      return(TC_EXPORT_ERROR); 
+	      tc_log_warn(MOD_NAME, "encoder error");
+	      return(TC_EXPORT_ERROR);
 	  }
       }
-      
+
       // first pass of two-pass, save results
-      if(VbrMode==1) 
-	  VbrControl_update_2pass_vbr_analysis(key.is_key_frame, 
-					       key.motion_bits, 
-					       key.texture_bits, 
-					       key.total_bits, 
+      if(VbrMode==1)
+	  VbrControl_update_2pass_vbr_analysis(key.is_key_frame,
+					       key.motion_bits,
+					       key.texture_bits,
+					       key.total_bits,
 					       key.quantizer);
       break;
     }
@@ -688,67 +681,67 @@ MOD_encode
     // write bitstream
 
     /* split the AVI */
-    if((uint32_t)(AVI_bytes_written(avifile)+encode.length+16+8)>>20 >= tc_avi_limit) 
+    if((uint32_t)(AVI_bytes_written(avifile)+encode.length+16+8)>>20 >= tc_avi_limit)
 	tc_outstream_rotate_request();
 
     //0.6.2: switch outfile on "C" and -J pv
     if(key.is_key_frame) tc_outstream_rotate();
-  
+
     if(AVI_write_frame(avifile, buffer, encode.length, key.is_key_frame)<0) {
-	fprintf(stderr, "DivX avi video write error\n");
-	return(TC_EXPORT_ERROR); 
+	tc_log_warn(MOD_NAME, "DivX avi video write error");
+	return(TC_EXPORT_ERROR);
     }
 #endif
-    
+
     return(0);
   }
-  
-  if(param->flag == TC_AUDIO) return(audio_encode(param->buffer, param->size, avifile));  
-  
+
+  if(param->flag == TC_AUDIO) return(tc_audio_encode(param->buffer, param->size, avifile));
+
   // invalid flag
-  return(TC_EXPORT_ERROR); 
+  return(TC_EXPORT_ERROR);
 }
 
-/* ------------------------------------------------------------ 
+/* ------------------------------------------------------------
  *
  * close codec
  *
  * ------------------------------------------------------------*/
 
 MOD_close
-{  
+{
 
   vob_t *vob = tc_get_vob();
-  if(param->flag == TC_AUDIO) return(audio_close()); 
-    
+  if(param->flag == TC_AUDIO) return(tc_audio_close());
+
   if(vob->avifile_out!=NULL) {
     AVI_close(vob->avifile_out);
     vob->avifile_out=NULL;
   }
-  
+
   if(param->flag == TC_VIDEO) return(0);
-  
-  return(TC_EXPORT_ERROR); 
+
+  return(TC_EXPORT_ERROR);
 }
 
 
-/* ------------------------------------------------------------ 
+/* ------------------------------------------------------------
  *
  * stop encoder
  *
  * ------------------------------------------------------------*/
 
 MOD_stop
-{  
+{
 
-  if(param->flag == TC_VIDEO) { 
+  if(param->flag == TC_VIDEO) {
 #if ENCORE_VERSION >= 20021024
     if(divx5_encore(encore_handle, ENC_OPT_RELEASE, NULL, NULL) < 0) {
-      tc_warn("DivX encoder close error\n");
+      tc_log_warn(MOD_NAME, "DivX encoder close error");
     }
 #else
     if(divx5_encore(divx->handle, ENC_OPT_RELEASE, NULL, NULL) < 0) {
-      fprintf(stderr, "DivX encoder close error\n");
+      tc_log_warn(MOD_NAME, "DivX encoder close error");
     }
 #endif
 
@@ -756,14 +749,14 @@ MOD_stop
 	free(buffer);
 	buffer=NULL;
     }
-    
+
     //remove codec
     dlclose(handle);
-    
+
 #if ENCORE_VERSION >= 20021024
 #else
     switch(VbrMode) {
-	
+
     case 1:
     case 2:
     case 3:
@@ -774,12 +767,12 @@ MOD_stop
 	break;
     }
 #endif
-    
+
     return(0);
   }
 
-  if(param->flag == TC_AUDIO) return(audio_stop());  
-  
-  return(TC_EXPORT_ERROR);     
+  if(param->flag == TC_AUDIO) return(tc_audio_stop());
+
+  return(TC_EXPORT_ERROR);
 }
 
