@@ -1,7 +1,7 @@
 /*
  *  export_pcm.c
  *
- *  Copyright (C) Thomas streich - May 2002
+ *  Copyright (C) Thomas Oestreich - May 2001
  *
  *  This file is part of transcode, a video stream processing tool
  *      
@@ -27,18 +27,18 @@
 #include <errno.h>
 
 #include "transcode.h"
-#include "avilib.h"
-#include "ioaux.h"
+#include "avilib/avilib.h"
+#include "libtc/libtc.h"
 
 #define MOD_NAME    "export_pcm.so"
-#define MOD_VERSION "v0.0.5 (2006-01-30)"
+#define MOD_VERSION "v0.1.0 (2007-08-25)"
 #define MOD_CODEC   "(audio) PCM (non-interleaved)"
 
 
 static int verbose_flag=TC_QUIET;
 static int capability_flag=TC_CAP_PCM|TC_CAP_RGB|TC_CAP_YUV|TC_CAP_VID;
 
-#define MOD_PRE wav
+#define MOD_PRE tc_pcm
 #include "export_def.h"
 
 static struct wave_header rtf;
@@ -48,8 +48,8 @@ static int fd_ls = -1, fd_rs = -1, fd_lfe = -1;
 typedef enum {
     CHANNEL_CENTER = 1,
     CHANNEL_STEREO = 2,
-    CHANNEL_FRONT = 4,
-    CHANNEL_LFE = 8
+    CHANNEL_FRONT  = 4,
+    CHANNEL_LFE    = 8
 } PCMChannels;
 
 static PCMChannels chan_settings[8] = {
@@ -74,7 +74,7 @@ MOD_init
     int rate;
 
     if (param->flag == TC_VIDEO) {
-        return(TC_EXPORT_OK);
+        return TC_EXPORT_OK;
     }
     if (param->flag == TC_AUDIO) {
         memset(&rtf, 0, sizeof(rtf));
@@ -96,17 +96,17 @@ MOD_init
         if(vob->dm_chan >= 1 && vob->dm_chan <= 6) { /* sanity check */
             rtf.common.wChannels=vob->dm_chan;
         } else {
-            fprintf(stderr, "[%s] Bad PCM channel number: %i\n",
-                            MOD_NAME, vob->dm_chan);
-            return(TC_EXPORT_ERROR);
+            tc_log_error(MOD_NAME, "bad PCM channel number: %i",
+                                   vob->dm_chan);
+            return TC_EXPORT_ERROR;
         }
-        if (!vob->fixme_a_codec
+        if (!vob->a_codec_flag
           || !rtf.common.dwSamplesPerSec
           || !rtf.common.wBitsPerSample
           || !rtf.common.wBlockAlign) {
-            fprintf(stderr, "[%s] Cannot export PCM, invalid format "
-                            "(no audio track at all?)", MOD_NAME);
-            return(TC_EXPORT_ERROR);
+            tc_log_error(MOD_NAME, "cannot export PCM, invalid format "
+                                   "(no audio track at all?)");
+            return TC_EXPORT_ERROR;
         }
 
         rtf.riff.len = 0x7FFFFFFF;
@@ -114,10 +114,10 @@ MOD_init
 
         strlcpy(rtf.data.id, "data",4);
 
-        return(TC_EXPORT_OK);
+        return TC_EXPORT_OK;
     }
     // invalid flag
-    return(TC_EXPORT_ERROR); 
+    return TC_EXPORT_ERROR; 
 }
 
 /* ------------------------------------------------------------ 
@@ -131,59 +131,58 @@ MOD_init
     fd = open(fname, O_RDWR|O_CREAT|O_TRUNC, \
 	                 S_IRUSR|S_IWUSR|S_IRGRP|S_IWGRP|S_IROTH|S_IWOTH); \
     if (fd < 0) { \
-        fprintf(stderr, "[%s] opening file: %s\n", \
-                        MOD_NAME, strerror(errno)); \
-        return(TC_EXPORT_ERROR); \
+        tc_log_error(MOD_NAME, "opening file: %s", strerror(errno)); \
+        return TC_EXPORT_ERROR; \
     } \
 } while (0)
 
 MOD_open
 {
-    char fname[256];
+    char fname[TC_BUF_LINE];
     int chan_flags = chan_settings[rtf.common.wChannels];  
 
     if (param->flag == TC_AUDIO) {
         if (chan_flags & CHANNEL_LFE) {
-            snprintf(fname, sizeof(fname), "%s_lfe.pcm",
-                     vob->audio_out_file);
+            tc_snprintf(fname, sizeof(fname), "%s_lfe.pcm",
+                        vob->audio_out_file);
             FD_OPEN(fd_lfe);
         }
 	
         if (chan_flags & CHANNEL_FRONT) {
-	        snprintf(fname, sizeof(fname), "%s_ls.pcm",
-                            vob->audio_out_file);
+	        tc_snprintf(fname, sizeof(fname), "%s_ls.pcm",
+                        vob->audio_out_file);
             FD_OPEN(fd_ls);
 	  
-            snprintf(fname, sizeof(fname), "%s_rs.pcm",
-                            vob->audio_out_file);
+            tc_snprintf(fname, sizeof(fname), "%s_rs.pcm",
+                        vob->audio_out_file);
             FD_OPEN(fd_rs);
         }
  
         if (chan_flags & CHANNEL_STEREO) {
-	        snprintf(fname, sizeof(fname), "%s_l.pcm",
-                            vob->audio_out_file);
+	        tc_snprintf(fname, sizeof(fname), "%s_l.pcm",
+                        vob->audio_out_file);
             FD_OPEN(fd_l);
 	  
-            snprintf(fname, sizeof(fname), "%s_r.pcm",
-                            vob->audio_out_file);
+            tc_snprintf(fname, sizeof(fname), "%s_r.pcm",
+                        vob->audio_out_file);
 	        FD_OPEN(fd_r); 
         }
 
         if (chan_flags & CHANNEL_CENTER) {
-	        snprintf(fname, sizeof(fname), "%s_c.pcm",
-                            vob->audio_out_file);
+	        tc_snprintf(fname, sizeof(fname), "%s_c.pcm",
+                        vob->audio_out_file);
             FD_OPEN(fd_c);
         }
 
-        return(TC_EXPORT_OK);
+        return TC_EXPORT_OK;
     }
 
     if (param->flag == TC_VIDEO) {
-        return(TC_EXPORT_OK);
+        return TC_EXPORT_OK;
     }
   
     // invalid flag
-    return(TC_EXPORT_ERROR); 
+    return TC_EXPORT_ERROR; 
 }   
 
 /* ------------------------------------------------------------ 
@@ -193,34 +192,34 @@ MOD_open
  * ------------------------------------------------------------*/
 
 #define FD_WRITE(fd, buf, size) do { \
-      if(fd != -1 && p_write(fd, buf, size) != size) { \
-          fprintf(stderr, "[%s] writing audio frame: %s\n", \
-                          MOD_NAME, strerror(errno)); \
-          return(TC_EXPORT_ERROR); \
+      if(fd != -1 && tc_pwrite(fd, buf, size) != size) { \
+          tc_log_error(MOD_NAME,  "writing audio frame: %s", \
+                       strerror(errno)); \
+          return TC_EXPORT_ERROR; \
       } \
 } while (0)
 
 MOD_encode
 {
     if (param->flag == TC_VIDEO) {
-        return(TC_EXPORT_OK);
+        return TC_EXPORT_OK;
     }
     if (param->flag == TC_AUDIO) { 
         int size = (int)(param->size/rtf.common.wChannels);
     
         switch (rtf.common.wChannels) {
           case 6:
-            FD_WRITE(fd_rs, param->buffer + 5*size, size);
-            FD_WRITE(fd_ls, param->buffer + 4*size, size);
-            FD_WRITE(fd_r, param->buffer + 3*size, size);
-            FD_WRITE(fd_c, param->buffer + 2*size, size);
-            FD_WRITE(fd_l, param->buffer + size, size);
-            FD_WRITE(fd_lfe, param->buffer, size);
+            FD_WRITE(fd_rs,  param->buffer + 5 * size, size);
+            FD_WRITE(fd_ls,  param->buffer + 4 * size, size);
+            FD_WRITE(fd_r,   param->buffer + 3 * size, size);
+            FD_WRITE(fd_c,   param->buffer + 2 * size, size);
+            FD_WRITE(fd_l,   param->buffer +     size, size);
+            FD_WRITE(fd_lfe, param->buffer,            size);
             break;
 
           case 2:
             FD_WRITE(fd_r, param->buffer + size, size);
-            FD_WRITE(fd_l, param->buffer, size);
+            FD_WRITE(fd_l, param->buffer,        size);
             break;
       
           case 1:
@@ -228,11 +227,11 @@ MOD_encode
             break;
         }
 
-        return(TC_EXPORT_OK);
+        return TC_EXPORT_OK;
     }
   
     // invalid flag
-    return(TC_EXPORT_ERROR);
+    return TC_EXPORT_ERROR;
 }
 
 /* ------------------------------------------------------------ 
@@ -250,7 +249,7 @@ MOD_encode
 MOD_close
 {  
     if (param->flag == TC_VIDEO) {
-        return(TC_EXPORT_OK);
+        return TC_EXPORT_OK;
     }
     if (param->flag == TC_AUDIO) {
         FD_CLOSE(fd_l);
@@ -259,9 +258,9 @@ MOD_close
         FD_CLOSE(fd_ls);
         FD_CLOSE(fd_rs);
         FD_CLOSE(fd_lfe);
-        return(TC_EXPORT_OK);
+        return TC_EXPORT_OK;
     }
-    return(TC_EXPORT_ERROR);  
+    return TC_EXPORT_ERROR;  
 }
 
 /* ------------------------------------------------------------ 
@@ -273,11 +272,22 @@ MOD_close
 MOD_stop 
 {
     if (param->flag == TC_VIDEO) {
-        return(TC_EXPORT_OK);
+        return TC_EXPORT_OK;
     }
     if (param->flag == TC_AUDIO) {
-        return(TC_EXPORT_OK);
+        return TC_EXPORT_OK;
     }
-    return(TC_EXPORT_ERROR);
+    return TC_EXPORT_ERROR;
 }
 
+/*************************************************************************/
+
+/*
+ * Local variables:
+ *   c-file-style: "stroustrup"
+ *   c-file-offsets: ((case-label . *) (statement-case-intro . *))
+ *   indent-tabs-mode: nil
+ * End:
+ *
+ * vim: expandtab shiftwidth=4:
+ */
