@@ -1,11 +1,8 @@
 #ifndef __FFMPEG_CFG_H
 #define __FFMPEG_CFG_H
 
-#include <libavcodec/avcodec.h>
-
-#include "libioaux/configs.h"
-#include "transcode.h"
-
+#include "libtc/cfgfile.h"
+#include "libtc/tcavcodec.h"
 
 //char *lavc_param_vcodec = "mpeg4";
 //extern int lavc_param_vbitrate;
@@ -103,6 +100,9 @@ extern int lavc_param_intra_dc_precision;
 extern int lavc_param_skip_top;
 extern int lavc_param_skip_bottom;
 
-extern struct config lavcopts_conf[];
+extern char *lavc_param_video_preset;
+extern char *lavc_param_ffmpeg_datadir;
+
+extern TCConfigEntry lavcopts_conf[];
 
 #endif
