@@ -3,27 +3,27 @@
  *
  *  Copyright (C) Marrq - July 2003
  *
- *  This file is part of transcode, a linux video stream processing tool
+ *  This file is part of transcode, a video stream processing tool
  *  Based on the excellent work of Donald Graft in Decomb and of
  *  Thanassis Tsiodras of transcode's decimate filter and Tilmann Bitterberg
- *      
+ *
  *  transcode is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 2, or (at your option)
  *  any later version.
- *   
+ *
  *  transcode is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
- *   
+ *
  *  You should have received a copy of the GNU General Public License
  *  along with GNU Make; see the file COPYING.  If not, write to
- *  the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA. 
+ *  the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
  *
  */
 
-// ----------------- Changes 
+// ----------------- Changes
 // 0.9 -> 0.10: marrq
 //		added scene change detection code courtesy of Tilmann Bitterberg
 //		so we won't blend if there's a change of scene (we'll still interpolate)
@@ -52,33 +52,16 @@
 #define MOD_VERSION "v0.10 (2003-08-18)"
 #define MOD_CAP     "plugin to modify framerate"
 #define MOD_AUTHOR  "Marrq"
-//#define DEBUG 1
-
-#include <stdio.h>
-#include <stdlib.h>
-#include <sys/stat.h>
-#include <unistd.h>
-#include <inttypes.h>
-
-/* -------------------------------------------------
- *
- * mandatory include files
- *
- *-------------------------------------------------*/
-
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
-#include <unistd.h>
-#include <inttypes.h>
-#include <math.h>
 
 #include "transcode.h"
-#include "framebuffer.h"
-#include "optstr.h"
+#include "filter.h"
+#include "libtc/libtc.h"
+#include "libtc/optstr.h"
+#include "libtc/ratiocodes.h"
 
-// FIXME
-extern long int lrint(double x);
+#include <math.h>
+
+//#define DEBUG 1
 
 static int show_results=0;
 
@@ -104,37 +87,40 @@ static int *framesOK, *framesScore;
 static int scanrange = 0;
 static int clonetype = 0;
 
-static double frc_table[16] = {0,
-			       NTSC_FILM, 24, 25, NTSC_VIDEO, 30, 50, 
-			       (2*NTSC_VIDEO), 60,
-			       1, 5, 10, 12, 15, 
-			       0, 0};
-static void help_optstr()
+static void help_optstr(void)
 {
-    printf("[%s] (%s) help\n", MOD_NAME, MOD_CAP);
-    printf ("* Overview\n");
-    printf ("  This filter aims to allow transcode to alter the fps\n");
-    printf ("  of video.  While one can reduce the fps to any amount,\n");
-    printf ("  one can only increase the fps to at most twice the\n");
-    printf ("  original fps\n");
-    printf ("  There are two modes of operation, buffered and unbuffered,\n");
-    printf ("  unbuffered is quick, but buffered, especially when dropping frames\n");
-    printf ("  should look better\n");
-    printf ("  For most users, modfps will need either no options, or just mode=1\n");
-    printf ("* Options\n");
-    printf ("\tmode : (0=unbuffered, 1=buffered [%d]\n", mode);
-    printf ("\tinfps : original fps (override what transcode supplies) [%f]\n",infps);
-    printf ("\tinfrc : original frc (overwrite infps) [%d]\n",infrc);
-    printf ("\tbuffer : number of frames to buffer [%d]\n",numSample);
-    printf ("\tsubsample : number of pixels to subsample when examining buffers [%d]\n",offset);
-    printf ("\tclonetype : when cloning and mode=1 do something special [%d]\n",clonetype);
-    printf ("\t\t    0 = none\n");
-    printf ("\t\t    1 = merge fields, cloned frame first(good for interlaced displays)\n");
-    printf ("\t\t    2 = merge fields, cloned frame 2nd (good for interlaced displays)\n");
-    printf ("\t\t    3 = average frames\n");
-    printf ("\t\t    4 = temporally average frame\n");
-    printf ("\t\t    5 = pseudo-phosphor average frames (YUV only) (slow)\n");
-    printf ("\tverbose : 0 = not verbose, 1 is verbose [%d]\n",show_results);
+    tc_log_info(MOD_NAME, "(%s) help\n"
+"* Overview\n"
+"  This filter aims to allow transcode to alter the fps\n"
+"  of video.  While one can reduce the fps to any amount,\n"
+"  one can only increase the fps to at most twice the\n"
+"  original fps\n"
+"  There are two modes of operation, buffered and unbuffered,\n"
+"  unbuffered is quick, but buffered, especially when dropping frames\n"
+"  should look better\n"
+"  For most users, modfps will need either no options, or just mode=1\n"
+"* Options\n"
+"    mode : (0=unbuffered, 1=buffered [%d]\n"
+"    infps : original fps (override what transcode supplies) [%f]\n"
+"    infrc : original frc (overwrite infps) [%d]\n"
+"    buffer : number of frames to buffer [%d]\n"
+"    subsample : number of pixels to subsample when examining buffers [%d]\n"
+"    clonetype : when cloning and mode=1 do something special [%d]\n"
+"        0 = none\n"
+"        1 = merge fields, cloned frame first(good for interlaced displays)\n"
+"        2 = merge fields, cloned frame 2nd (good for interlaced displays)\n"
+"        3 = average frames\n"
+"        4 = temporally average frame\n"
+"        5 = pseudo-phosphor average frames (YUV only) (slow)\n"
+"    verbose : 0 = not verbose, 1 is verbose [%d]\n"
+		, MOD_CAP,
+		mode,
+		infps,
+		infrc,
+		numSample,
+		offset,
+		clonetype,
+		show_results);
 }
 
 #define ABS_u8(a) (((a)^((a)>>7))-((a)>>7))
@@ -210,20 +196,11 @@ static void clone_phosphor_average(unsigned char *clone, unsigned char *next, vf
   // let's not blend if there's a scenechange
   if (tc_detect_scenechange(clone,next,ptr)){
     return;
-  } // else 
+  } // else
   for(i=0;i<(ptr->v_width*ptr->v_height);i++){
-    //ptr->video_buf[i] = (unsigned char)lrint(pow( ( pow((double)clone[i], 3.0) +
-    //					      pow((double)next[i],  3.0) ) / 2.0,
-    //					      1.0/3.0));
-#ifdef HAVE_LIBM_LRINT
-    ptr->video_buf[i] = (unsigned char)lrint(pow((double) (( clone[i]*clone[i]*clone[i] +
-    					      next[i]*next[i]*next[i]) >> 1),
-					      1.0/3.0));
-#else
     ptr->video_buf[i] = (unsigned char)(long)rint(pow((double) (( clone[i]*clone[i]*clone[i] +
     					      next[i]*next[i]*next[i]) >> 1),
 					      1.0/3.0));
-#endif
   }
   for(; i<ptr->video_size; i++){
     ptr->video_buf[i] = (unsigned char)( ((short int)clone[i] + (short int)next[i]) >> 1);
@@ -236,7 +213,7 @@ static void clone_average(unsigned char *clone, unsigned char *next, vframe_list
   // let's not blend if there's a scenechange
   if (tc_detect_scenechange(clone,next,ptr)){
     return;
-  } // else 
+  } // else
   for(i=0;i<ptr->video_size;i++){
     ptr->video_buf[i] = (unsigned char)( ((short int)clone[i] + (short int)next[i]) >> 1);
   }
@@ -248,13 +225,13 @@ static void clone_temporal_average(unsigned char *clone, unsigned char*next, vfr
   // perfectly placed  since's we'll be merging the tin and the tin+1
   // frame into the tout'th frame, we calculate the time that
   // tout will be played at, and compare it to tin and tin+1
-  
+
   // because the main body is buffering frames, when we're called, tin and tout might
   // not be appropriate for when clones should be called (in otherwords, the
   // buffering allows a small amount of AV slippage) ... what this means, is
   // that sometimes to have things match up temporally best, we should just
   // copy in the next frame  This tends to happen when outfps < 1.5*infps
-  
+
   double weight1,weight2;
   int i;
   static int first=1;
@@ -262,37 +239,38 @@ static void clone_temporal_average(unsigned char *clone, unsigned char*next, vfr
   weight1 = 1.0 - ( (double)tout/outfps*infps - (double)tin );
   weight2 = 1.0 - ( (double)(tin+1) - (double)(tout)/outfps*infps );
   // weight2 is also 1.0-weight1
-  
+
   if (show_results){
-    printf("[%s] temporal_clone tin=%4d tout=%4d w1=%1.5f w2=%1.5f\n",MOD_NAME,tin,tout,weight1,weight2);
+    tc_log_info(MOD_NAME, "temporal_clone tin=%4d tout=%4d w1=%1.5f w2=%1.5f",
+                    tin,tout,weight1,weight2);
   }
 
   if (weight1 < 0.0){
     if (show_results){
-      printf("[%s] temporal_clone: w1 is weak, copying next frame\n",MOD_NAME);
+      tc_log_info(MOD_NAME, "temporal_clone: w1 is weak, copying next frame");
     }
-    tc_memcpy(ptr->video_buf,next,ptr->video_size);
+    ac_memcpy(ptr->video_buf,next,ptr->video_size);
     return;
   } // else
   if (weight2 < 0.0){
     // I think this case cannot happen
     if (show_results){
-      printf("[%s] temporal_clone: w2 is weak, simple cloning of frame\n",MOD_NAME);
+      tc_log_info(MOD_NAME, "temporal_clone: w2 is weak, simple cloning of frame");
     }
     // no memcpy needed, as we're keeping the orig
     return;
   } // else
-  
+
   // let's not blend if there's a scenechange
   if (tc_detect_scenechange(clone,next,ptr)){
     return;
-  } // else 
+  } // else
 
   if (weight1 > 1.0 || weight2 > 1.0){
-    fprintf(stderr, "[%s] clone_temporal_average: error: weights are out of range, w1=%f w2=%f\n", MOD_NAME,weight1,weight2);
+    tc_log_info(MOD_NAME, "clone_temporal_average: error: weights are out of range, w1=%f w2=%f", weight1,weight2);
     return;
-  } // else 
-  
+  } // else
+
   for(i=0; i<ptr->video_size; i++){
     ptr->video_buf[i] = (unsigned char)( (double)(clone[i])*weight1 + (double)(next[i])*weight2);
   }
@@ -318,11 +296,11 @@ static void clone_interpolate(char *clone, char *next, vframe_list_t *ptr){
   s1 = clone;
   s2 = next+width;
   for(i=0;i<height;i++){
-    tc_memcpy(dest,s1,width);
+    ac_memcpy(dest,s1,width);
     dest += width;
     // check to make sure we don't have an odd number of rows;
     if (++i < height){
-      tc_memcpy(dest,s2,width);
+      ac_memcpy(dest,s2,width);
       dest += width;
       s1 += width<<1;
       s2 += width<<1;
@@ -339,11 +317,11 @@ static void clone_interpolate(char *clone, char *next, vframe_list_t *ptr){
     // we don't have to divide the height by 2 because we've
     // got two colors, we'll handle them in one sweep.
     for(i=0;i<height;i++){
-      tc_memcpy(dest,s1,width);
+      ac_memcpy(dest,s1,width);
       dest+=width;
       // check to make sure we don't have an odd number of rows;
       if(++i < height){
-        tc_memcpy(dest,s2,width);
+        ac_memcpy(dest,s2,width);
 	dest += width;
 	s1 += width<<1;
 	s2 += width<<1;
@@ -359,13 +337,12 @@ static void clone_interpolate(char *clone, char *next, vframe_list_t *ptr){
  ******/
 static void fancy_clone(char* clone, char* next, vframe_list_t *ptr, int tin, int tout){
   if ((ptr == NULL) || (clone == NULL) || (next == NULL) || (ptr->video_buf == NULL)){
-    fprintf(stderr,"[%s] Big error; we're about to dereference NULL\n",MOD_NAME);
+    tc_log_error(MOD_NAME, "Big error; we're about to dereference NULL");
     return;
   }
-  //printf("[%s] fancy_clone clonetype: %d tin=%4d tout=%4d\n",MOD_NAME,clonetype,tin,tout);
   switch (clonetype){
     case 0:
-      tc_memcpy(ptr->video_buf,clone,ptr->video_size);
+      ac_memcpy(ptr->video_buf,clone,ptr->video_size);
       break;
     case 1:
       clone_interpolate(clone,next,ptr);
@@ -381,13 +358,13 @@ static void fancy_clone(char* clone, char* next, vframe_list_t *ptr, int tin, in
       break;
     case 5:
       if (ptr->v_codec != CODEC_YUV){
-        printf("[%s] Erroor, phosphor merge only implemented for YUV data\n",MOD_NAME);
+        tc_log_error(MOD_NAME, "phosphor merge only implemented for YUV data");
 	return;
       }
       clone_phosphor_average(clone,next,ptr);
       break;
     default:
-      printf("[%s] Error, unimplemented clonetype\n",MOD_NAME);
+      tc_log_error(MOD_NAME, "unimplemented clonetype");
       break;
   }
   return;
@@ -410,30 +387,31 @@ static int memory_init(vframe_list_t * ptr){
 
   if (scanrange > ptr->video_size){
     // error, we'll overwalk boundaries later on
-    fprintf(stderr, "[%s] Error, video_size doesn't look to be big enough (scan=%d video_size=%d).\n",MOD_NAME,scanrange,ptr->video_size);
+    tc_log_error(MOD_NAME, "video_size doesn't look to be big enough (scan=%d video_size=%d).",
+                    scanrange,ptr->video_size);
     return -1;
   }
-  
-  frames = (char**)malloc(sizeof (char*)*frbufsize);
+
+  frames = tc_malloc(sizeof (char*)*frbufsize);
   if (NULL == frames){
-    fprintf(stderr, "[%s] Error allocating memory in init\n",MOD_NAME);
+    tc_log_error(MOD_NAME, "Error allocating memory in init");
     return -1;
   } // else
   for (i=0;i<frbufsize; i++){
-    frames[i] = (char*)malloc(sizeof(char)*ptr->video_size);
+    frames[i] = tc_malloc(sizeof(char)*ptr->video_size);
     if (NULL == frames[i]){
-      fprintf(stderr, "[%s] Error allocating memory in init\n",MOD_NAME);
+      tc_log_error(MOD_NAME, "Error allocating memory in init");
       return -1;
     }
   }
-  framesOK = (int*)malloc(sizeof(int)*frbufsize);
+  framesOK = tc_malloc(sizeof(int)*frbufsize);
   if (NULL == framesOK){
-    fprintf(stderr, "[%s] Error allocating memory in init\n",MOD_NAME);
+    tc_log_error(MOD_NAME, "Error allocating memory in init");
     return -1;
   }
-  framesScore = (int*)malloc(sizeof(int)*frbufsize);
+  framesScore = tc_malloc(sizeof(int)*frbufsize);
   if (NULL == framesScore){
-    fprintf(stderr, "[%s] Error allocating memory in init\n",MOD_NAME);
+    tc_log_error(MOD_NAME, "Error allocating memory in init");
     return -1;
   }
   if (mode == 1){
@@ -442,8 +420,9 @@ static int memory_init(vframe_list_t * ptr){
   return -1;
 }
 
-int tc_filter(vframe_list_t * ptr, char *options)
+int tc_filter(frame_list_t *ptr_, char *options)
 {
+    vframe_list_t *ptr = (vframe_list_t *)ptr_;
     static vob_t *vob = NULL;
     static int framesin = 0;
     static int init = 1;
@@ -474,7 +453,7 @@ int tc_filter(vframe_list_t * ptr, char *options)
 	  }
 	  optstr_get (options, "verbose", "%d", &show_results);
 	  optstr_get (options, "mode", "%d", &mode);
-	  optstr_get (options, "infps", "%f", &infps);
+	  optstr_get (options, "infps", "%lf", &infps);
 	  optstr_get (options, "infrc", "%d", &infrc);
 	  optstr_get (options, "buffer", "%d", &numSample);
 	  optstr_get (options, "subsample", "%d", &offset);
@@ -483,22 +462,22 @@ int tc_filter(vframe_list_t * ptr, char *options)
 	}
 
 	if (infrc>0 && infrc < 16){
-	  infps = frc_table[infrc];
+	  tc_frc_code_to_value(infrc, &infps);
 	}
 
 	if (verbose){
-	  printf("[%s] %s %s\n", MOD_NAME, MOD_VERSION, MOD_CAP);
-	  printf("[%s] converting from %2.4ffps to %2.4ffps\n",MOD_NAME,infps,outfps);
+	  tc_log_info(MOD_NAME, "%s %s", MOD_VERSION, MOD_CAP);
+	  tc_log_info(MOD_NAME, "converting from %2.4ffps to %2.4ffps",infps,outfps);
 	}
 
 	if (outfps > infps*2.0){
-	  fprintf(stderr, "[%s] Error, desired output fps can not be greater\n",MOD_NAME);
-	  fprintf(stderr, "[%s] than twice the input fps\n", MOD_NAME);
+	  tc_log_error(MOD_NAME, "desired output fps can not be greater");
+	  tc_log_error(MOD_NAME, "than twice the input fps");
 	  return -1;
 	}
 
 	if ( (outfps == infps) || (infrc && infrc == vob->ex_frc)) {
-	  fprintf(stderr, "[%s] No framerate conversion requested, exiting\n",MOD_NAME);
+	  tc_log_error(MOD_NAME, "No framerate conversion requested, exiting");
 	  return -1;
 	}
 
@@ -513,7 +492,7 @@ int tc_filter(vframe_list_t * ptr, char *options)
 	  return 0;
 	} // else
 
-	fprintf (stderr, "[%s] Error, only two modes of operation.\n",MOD_NAME);
+	tc_log_error(MOD_NAME, "only two modes of operation.");
 	return -1;
     }
 
@@ -521,19 +500,19 @@ int tc_filter(vframe_list_t * ptr, char *options)
       char buf[255];
       optstr_filter_desc (options, MOD_NAME, MOD_CAP, MOD_VERSION, MOD_AUTHOR, "VYRE", "1");
 
-      sprintf(buf, "%d",mode);
+      tc_snprintf(buf, sizeof(buf), "%d",mode);
       optstr_param(options,"mode","mode of operation", "%d", buf, "0", "1");
-      snprintf(buf, 128, "%f", infps);
+      tc_snprintf(buf, sizeof(buf), "%f", infps);
       optstr_param(options, "infps", "Original fps", "%f", buf, "MIN_FPS", "200.0");
-      snprintf(buf, 128, "%d", infrc);
+      tc_snprintf(buf, sizeof(buf), "%d", infrc);
       optstr_param(options, "infrc", "Original frc", "%d", buf, "0", "16");
-      sprintf(buf, "%d", numSample);
+      tc_snprintf(buf, sizeof(buf), "%d", numSample);
       optstr_param(options,"examine", "How many frames to buffer", "%d", buf, "2", "25");
-      sprintf(buf, "%d", offset);
+      tc_snprintf(buf, sizeof(buf), "%d", offset);
       optstr_param(options, "subsample", "How many pixels to subsample", "%d", buf, "1", "256");
-      sprintf(buf, "%d", clonetype);
+      tc_snprintf(buf, sizeof(buf), "%d", clonetype);
       optstr_param(options, "clonetype", "How to clone frames", "%d", buf, "0", "16");
-      sprintf(buf, "%d", verbose);
+      tc_snprintf(buf, sizeof(buf), "%d", verbose);
       optstr_param(options, "verbose", "run in verbose mode", "%d", buf, "0", "1");
       return 0;
     }
@@ -546,7 +525,7 @@ int tc_filter(vframe_list_t * ptr, char *options)
 
 
     if (ptr->tag & TC_FILTER_CLOSE) {
-	
+
 	return (0);
     }
     //----------------------------------
@@ -563,8 +542,9 @@ int tc_filter(vframe_list_t * ptr, char *options)
     if ((ptr->tag & runnow) && (ptr->tag & TC_VIDEO)) {
       if (mode == 0){
         if (show_results){
-          printf("[%s] in=%5d out=%5d win=%05.3f wout=%05.3f ",MOD_NAME,framesin,outframes,(double)framesin/infps,outframes/outfps);
-	} 
+          tc_log_info(MOD_NAME, "in=%5d out=%5d win=%05.3f wout=%05.3f ",
+                          framesin,outframes,(double)framesin/infps,outframes/outfps);
+	}
         if (infps < outfps){
 	  // Notes; since we currently only can clone frames (and just clone
 	  // them once, we can at most double the input framerate.
@@ -572,28 +552,28 @@ int tc_filter(vframe_list_t * ptr, char *options)
 	    // we can't clone it again, so we'll record the outframe and exit
 	    ++outframes;
 	    if (show_results){
-	      printf("\n");
+	      tc_log_info(MOD_NAME, "\n");
 	    }
 	    return 0;
-	  } // else 
+	  } // else
 	  if ((double)framesin++/infps > (double)outframes++/outfps){
 	    if (show_results){
-	      printf("FRAME IS CLONED");
+	      tc_log_info(MOD_NAME, "FRAME IS CLONED");
 	    }
 	    ptr->attributes |= TC_FRAME_IS_CLONED;
 	  }
 	} else {
 	  if ((double)framesin++/infps > outframes / outfps){
-	       ++outframes; 
+	       ++outframes;
 	  } else {
 	    if (show_results){
-	      printf("FRAME IS SKIPPED");
+	      tc_log_info(MOD_NAME, "FRAME IS SKIPPED");
 	    }
 	    ptr->attributes |= TC_FRAME_IS_SKIPPED;
 	  }
 	}
 	if (show_results){
-	  printf("\n");
+	  tc_log_info(MOD_NAME, "\n");
 	}
 	return(0);
       } // else
@@ -607,7 +587,9 @@ int tc_filter(vframe_list_t * ptr, char *options)
 	  }
 	}
 	if (show_results){
-          printf("[%s] frameIn=%d frameOut=%d in=%5d out=%5d win=%05.3f wout=%05.3f ",MOD_NAME,frameIn,frameOut,framesin-numSample,outframes+cloneq,(double)(framesin-numSample)/infps,(double)(outframes+cloneq)/outfps);
+          tc_log_info(MOD_NAME, "frameIn=%d frameOut=%d in=%5d out=%5d win=%05.3f wout=%05.3f ",
+                          frameIn,frameOut,framesin-numSample,outframes+cloneq,
+                          (double)(framesin-numSample)/infps,(double)(outframes+cloneq)/outfps);
 	}
 	if (ptr->attributes & TC_FRAME_WAS_CLONED){
 	  // don't do anything.  Since it's cloned, we don't
@@ -616,20 +598,20 @@ int tc_filter(vframe_list_t * ptr, char *options)
 	  // as the user requests and then leave, but for now, we'll
 	  // just flee.
 	  if (framesOK[(frameIn+0)%frbufsize]){
-	    fprintf(stderr, "[%s] Oppps, this frame wasn't cloned but we thought it was\n",MOD_NAME);
+	    tc_log_warn(MOD_NAME, "this frame wasn't cloned but we thought it was");
 	  }
 	  ++outframes;
 	  --cloneq;
 	  if (show_results){
-	    printf("no slot needed for clones\n");
+	    tc_log_info(MOD_NAME, "no slot needed for clones");
 	  }
 	  fancy_clone(frames[frameIn],frames[(frameIn+1)%frbufsize],ptr,framesin-numSample,outframes+cloneq+1);
 	  return 0;
-	} // else 
-	tc_memcpy(frames[frameIn], ptr->video_buf, ptr->video_size);
+	} // else
+	ac_memcpy(frames[frameIn], ptr->video_buf, ptr->video_size);
 	framesOK[frameIn] = 1;
 #ifdef DEBUG
-	printf("Inserted frame %d into slot %d \n",framesin, frameIn);
+	tc_log_info(MOD_NAME, "Inserted frame %d into slot %d",framesin, frameIn);
 #endif // DEBUG
 
 	// Now let's look and see if we should compute a frame's
@@ -642,7 +624,7 @@ int tc_filter(vframe_list_t * ptr, char *options)
 	  t1 = frames[t];
 	  t2 = frames[frameIn];
 #ifdef DEBUG
-	    printf("score: slot=%d, t1=%p t2=%p ",
+	    tc_log_info(MOD_NAME, "score: slot=%d, t1=%p t2=%p ",
 	      t,t1,t2);
 #endif // DEBUG
 	  *score=0;
@@ -650,7 +632,7 @@ int tc_filter(vframe_list_t * ptr, char *options)
 	    *score += abs(t2[i] - t1[i]);
 	  }
 #ifdef DEBUG
-	    printf("score = %d\n",*score);
+	    tc_log_info(MOD_NAME, "score = %d\n",*score);
 #endif // DEBUG
 	}
 
@@ -662,7 +644,7 @@ int tc_filter(vframe_list_t * ptr, char *options)
 	  frameIn = (frameIn+1) % frbufsize;
 	  ++framesin;
 	  if (show_results){
-	    printf("\n");
+	    tc_log_info(MOD_NAME, "\n");
 	  }
 	  return 0;
 	} // else
@@ -675,12 +657,12 @@ int tc_filter(vframe_list_t * ptr, char *options)
 	    // we have to find a frame to clone
 	    int diff=-1, mod=-1;
 #ifdef DEBUG
-	      printf("start=%d end=%d\n",(frameIn+1)%frbufsize,frameIn);
+	      tc_log_info(MOD_NAME, "start=%d end=%d",(frameIn+1)%frbufsize,frameIn);
 #endif // DEBUG
 	    fflush(stdout);
 	    for(i=((frameIn+1)%frbufsize); i!=frameIn; i=((i+1)%frbufsize)){
 #ifdef DEBUG
-	        printf("i=%d Ok=%d Score=%d\n",i,framesOK[i],framesScore[i]);
+	        tc_log_info(MOD_NAME, "i=%d Ok=%d Score=%d",i,framesOK[i],framesScore[i]);
 #endif // DEBUG
 	      // make sure we haven't skipped/cloned this frame already
 	      if(framesOK[i]){
@@ -692,24 +674,24 @@ int tc_filter(vframe_list_t * ptr, char *options)
 	      }
 	    }
 	    if (mod == -1){
-	      fprintf(stderr,"[%s] Error calculating frame to clone\n",MOD_NAME);
+	      tc_log_error(MOD_NAME, "Error calculating frame to clone");
 	      return -1;
 	    }
 #ifdef DEBUG
-	    printf("XXX cloning  %d\n",mod);
+	    tc_log_info(MOD_NAME, "cloning  %d",mod);
 #endif // DEBUG
 	    ++cloneq;
 	    framesOK[mod] = 0;
 	  }
-	  tc_memcpy(ptr->video_buf,frames[frameOut],ptr->video_size);
+	  ac_memcpy(ptr->video_buf,frames[frameOut],ptr->video_size);
 	  if (framesOK[frameOut]){
 	    if (show_results){
-	      printf("giving   slot %2d frame %6d\n",frameOut,ptr->id);
+	      tc_log_info(MOD_NAME, "giving   slot %2d frame %6d",frameOut,ptr->id);
 	    }
 	  } else {
 	    ptr->attributes |= TC_FRAME_IS_CLONED;
 	    if (show_results){
-	      printf("cloning  slot %2d frame %6d\n",frameOut,ptr->id);
+	      tc_log_info(MOD_NAME, "cloning  slot %2d frame %6d",frameOut,ptr->id);
 	    }
 	  }
 	  frameOut = (frameOut+1) % frbufsize;
@@ -722,7 +704,7 @@ int tc_filter(vframe_list_t * ptr, char *options)
 	    // difference between the frame which follows it.
 	    for(i=((frameIn+1)%frbufsize); i!=frameIn; i=((i+1)%frbufsize)){
 #ifdef DEBUG
-	        printf("i=%d Ok=%d Score=%d\n",i,framesOK[i],framesScore[i]);
+	        tc_log_info(MOD_NAME, "i=%d Ok=%d Score=%d",i,framesOK[i],framesScore[i]);
 #endif // debug
 	      // make sure we haven't skipped/cloned this frame already
 	      if(framesOK[i]){
@@ -733,7 +715,7 @@ int tc_filter(vframe_list_t * ptr, char *options)
 	      }
 	    }
 	    if (mod == -1){
-	      fprintf(stderr,"[%s] Error calculating frame to skip\n",MOD_NAME);
+	      tc_log_error(MOD_NAME, "Error calculating frame to skip");
 	      return -1;
 	    }
 	    framesOK[mod] = 0;
@@ -741,14 +723,14 @@ int tc_filter(vframe_list_t * ptr, char *options)
 	    ++outframes;
 	  }
 	  if (framesOK[frameOut]){
-	    tc_memcpy(ptr->video_buf,frames[frameOut],ptr->video_size);
+	    ac_memcpy(ptr->video_buf,frames[frameOut],ptr->video_size);
 	    if (show_results){
-	      printf("giving   slot %2d frame %6d\n",frameOut,ptr->id);
+	      tc_log_info(MOD_NAME, "giving   slot %2d frame %6d",frameOut,ptr->id);
 	    }
 	  } else {
 	    ptr->attributes |= TC_FRAME_IS_SKIPPED;
 	    if (show_results){
-	      printf("skipping slot %2d frame %6d\n",frameOut,ptr->id);
+	      tc_log_warn(MOD_NAME, "skipping slot %2d frame %6d",frameOut,ptr->id);
 	    }
 	  }
 	  frameOut = (frameOut+1) % frbufsize;
@@ -757,7 +739,7 @@ int tc_filter(vframe_list_t * ptr, char *options)
 	++framesin;
 	return 0;
       }
-      fprintf(stderr, "[%s] Oppps, currently only 2 modes of operation\n",MOD_NAME);
+      tc_log_error(MOD_NAME, "currently only 2 modes of operation");
       return(-1);
     }
 
