@@ -1,10 +1,10 @@
 /*
     filter_smartyuv.c
-    
+
     This file is part of transcode, a video stream processing tool
-    
+
     2003 by Tilmann Bitterberg, based on code by Donald Graft.
-    
+
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
     the Free Software Foundation.
@@ -21,15 +21,16 @@
 */
 
 #define MOD_NAME    "filter_smartyuv.so"
-#define MOD_VERSION "0.1.4 (2003-10-13)"
+#define MOD_VERSION "0.1.6 (2007-05-31)"
 #define MOD_CAP     "Motion-adaptive deinterlacing"
 #define MOD_AUTHOR  "Tilmann Bitterberg"
 
 #include "transcode.h"
 #include "filter.h"
-#include "optstr.h"
+#include "libtc/libtc.h"
+#include "libtc/optstr.h"
 
-//#undef HAVE_MMX
+//#undef HAVE_ASM_MMX
 //#undef CAN_COMPILE_C_ALTIVEC
 
 // mmx gives a speedup of about 3 fps
@@ -48,37 +49,46 @@
 #define rdtscll(val) __asm__ __volatile__("rdtsc" : "=A" (val))
 
 
-static vob_t *vob=NULL;
+static vob_t *vob  = NULL;
 
 ///////////////////////////////////////////////////////////////////////////
 
 // this value is "hardcoded" in the optimized code for speed reasons
-#define DENOISE_DIAMETER 5
+enum {
+    FRAME_ONLY        = 0,
+    FIELD_ONLY        = 1,
+    FRAME_AND_FIELD   = 2,
 
-#define DENOISE_THRESH 7
-#define BLACK_BYTE_Y 16
-#define BLACK_BYTE_UV 128
-#define MIN_Y 16
-#define MAX_Y 240
-#define FRAME_ONLY 0
-#define FIELD_ONLY 1
-#define FRAME_AND_FIELD 2
+    DENOISE_DIAMETER  = 5,
+    DENOISE_THRESH    = 7,
 
-#define LUMA_THRESHOLD 14
-#define CHROMA_THRESHOLD 7
-#define SCENE_THRESHOLD 31
+    BLACK_BYTE_Y      = 16,
+    BLACK_BYTE_UV     = 128,
 
-// We pad the moving maps with 16 pixels left and right, to make sure
-// that we always can do aligned loads and stores at a multiple of 16.
-// this is especially important when doing altivec but might help in 
-// other cases as well.
-#define PAD 32
+    MIN_Y             = 16,
+    MAX_Y             = 240,
 
-static unsigned char clamp_Y(unsigned char x) {
-	return (x>MAX_Y?MAX_Y:(x<MIN_Y?MIN_Y:x));
+    LUMA_THRESHOLD    = 14,
+    CHROMA_THRESHOLD  = 7,
+    SCENE_THRESHOLD   = 31,
+
+    /*
+     * We pad the moving maps with 16 pixels left and right, to make sure
+     * that we always can do aligned loads and stores at a multiple of 16.
+     * this is especially important when doing altivec but might help in
+     * other cases as well.
+     */
+    PAD               = 32
+};
+
+typedef uint8_t (*yuv_clamp_fn)(int x);
+
+static uint8_t clamp_Y(int x) {
+    return ((TC_CLAMP(x, MIN_Y, MAX_Y)) & 0xFF);
 }
-static unsigned char clamp_UV(unsigned char x) {
-	return (x);
+
+static uint8_t clamp_UV(int x) {
+	return (x & 0xFF);
 }
 
 
@@ -88,117 +98,72 @@ count: 1-256
 stride: -32000 - 320000
 */
 
-#if 0 // unused, EMS
-static unsigned int get_prefetch_const (int blocksize_in_vectors, int block_count, int block_stride) 
-{
-    return ((blocksize_in_vectors<<24)&0x1F000000) | 
-	   ((block_count<<16)&0x00FF0000)          |
-	    (block_stride&0xFFFF);
-}
-#endif
-
-static unsigned char *bufalloc(size_t size, char *location)
-{
-
-#ifdef HAVE_GETPAGESIZE
-   long buffer_align=getpagesize();
-#else
-   long buffer_align=16;
-#endif
-
-   char *buf = malloc(size + buffer_align);
-
-   long adjust;
-
-   if (buf == NULL) {
-       fprintf(stderr, "(%s) out of memory", __FILE__);
-   }
-
-   location = buf;
-   
-   adjust = buffer_align - ((long) buf) % buffer_align;
-
-   if (adjust == buffer_align)
-      adjust = 0;
-
-   return (unsigned char *) (buf + adjust);
-}
-
-static void smartyuv_core (char *_src, char *_dst, char *_prev, int _width, int _height, 
-		int _srcpitch, int _dstpitch, 
-		unsigned char *_moving, unsigned char *_fmoving, 
-		unsigned char(*clamp_f)(unsigned char x), int _threshold );
+static void smartyuv_core (char *_src, char *_dst, char *_prev, int _width, int _height,
+                           int _srcpitch, int _dstpitch,
+                           unsigned char *_moving, unsigned char *_fmoving,
+                           yuv_clamp_fn clamp_f, int _threshold );
 
 typedef struct MyFilterData {
-        char                    *buf;
-	char			*prevFrame;
-	unsigned char		*movingY;
-	unsigned char		*movingU;
-	unsigned char		*movingV;
-	unsigned char		*fmovingY;
-	unsigned char		*fmovingU;
-	unsigned char		*fmovingV;
-	int			motionOnly;
-	int 			threshold;
-	int 			chromathres;
-	int                     codec;
-	int                     diffmode;
-	int			scenethreshold;
-	int			cubic;
-	int			highq;
-	int 			Blend;
-	int 			doChroma;
-	int 			verbose;
-
-	// These are the locations of the real malloc buffers
-        char                    *Rbuf;
-	char			*RprevFrame;
-	unsigned char		*RmovingY;
-	unsigned char		*RmovingU;
-	unsigned char		*RmovingV;
-	unsigned char		*RfmovingY;
-	unsigned char		*RfmovingU;
-	unsigned char		*RfmovingV;
+    char            *buf;
+    char            *prevFrame;
+    unsigned char   *movingY;
+    unsigned char   *movingU;
+    unsigned char   *movingV;
+    unsigned char   *fmovingY;
+    unsigned char   *fmovingU;
+    unsigned char   *fmovingV;
+    int             motionOnly;
+    int             threshold;
+    int             chromathres;
+    int             codec;
+    int             diffmode;
+    int             scenethreshold;
+    int             cubic;
+    int             highq;
+    int             Blend;
+    int             doChroma;
+    int             verbose;
 } MyFilterData;
 
-static MyFilterData *mfd;
+static MyFilterData *mfd = NULL;
 
-static void help_optstr(void) 
+static void help_optstr(void)
 {
-   printf ("[%s] (%s) help\n", MOD_NAME, MOD_CAP);
-   printf ("* Overview\n");
-   printf ("   This filter is basically a rewrite of the\n");
-   printf ("   smartdeinter filter by Donald Graft (without advanced processing\n");
-   printf ("   options) for YUV mode only. Its faster than using the smartdeinter\n");
-   printf ("   in YUV mode and is also tuned with its threshold settings for YUV\n");
-   printf ("   mode. The filter detects motion and static areas in an image and\n");
-   printf ("   only deinterlaces (either by blending or by cubic interpolation)\n");
-   printf ("   the moving areas. The result is an image with high detail in\n");
-   printf ("   static areas, no information is lost there.\n");
-   printf ("\n");
-   printf ("   The threshold settings should be sufficent for most users. As a\n");
-   printf ("   rule of thumb, I recommend setting the chroma threshold to about\n");
-   printf ("   the half of the luma threshold. If you want more deinterlacing,\n");
-   printf ("   lower the thresholds. The scene threshold can be easily found by\n");
-   printf ("   turning on verbose mode and the preview filter. In verbose mode,\n");
-   printf ("   the filter will print out, when it detects a scene change. If\n");
-   printf ("   scenechanges go by unnoticed, lower the scene threshold. You can\n");
-   printf ("   completly disable chroma processing with the doChroma=0 option.\n");
-   printf ("   Here is a sample commandline\n");
-   printf ("   -J smartyuv=highq=1:diffmode=2:cubic=1:Blend=1:chromathres=4:threshold=8:doChroma=1\n");
-   printf ("* Options\n");
-   printf ("  'motionOnly' Show motion areas only (0=off, 1=on) [0]\n");
-   printf ("    'diffmode' Motion Detection (0=frame, 1=field, 2=both) [0]\n");
-   printf ("   'threshold' Motion Threshold (luma) (0-255) [14]\n");
-   printf (" 'chromathres' Motion Threshold (chroma) (0-255) [7]\n");
-   printf ("  'scenethres' Threshold for detecting scenechanges (0-255) [31]\n");
-   printf ("       'cubic' Do cubic interpolation (0=off 1=on) [1]\n");
-   printf ("       'highq' High-Quality processing (motion Map denoising) (0=off 1=on) [1]\n");
-   printf ("       'Blend' Blend the frames for deinterlacing (0=off 1=on) [1]\n");
-   printf ("    'doChroma' Enable chroma processing (slower but more accurate) (0=off 1=on) [1]\n");
-   printf ("     'verbose' Verbose mode (0=off 1=on) [1]\n");
-
+   tc_log_info (MOD_NAME, "(%s) help\n"
+"* Overview\n"
+"   This filter is basically a rewrite of the\n"
+"   smartdeinter filter by Donald Graft (without advanced processing\n"
+"   options) for YUV mode only. Its faster than using the smartdeinter\n"
+"   in YUV mode and is also tuned with its threshold settings for YUV\n"
+"   mode. The filter detects motion and static areas in an image and\n"
+"   only deinterlaces (either by blending or by cubic interpolation)\n"
+"   the moving areas. The result is an image with high detail in\n"
+"   static areas, no information is lost there.\n"
+"\n"
+"   The threshold settings should be sufficent for most users. As a\n"
+"   rule of thumb, I recommend setting the chroma threshold to about\n"
+"   the half of the luma threshold. If you want more deinterlacing,\n"
+"   lower the thresholds. The scene threshold can be easily found by\n"
+"   turning on verbose mode and the preview filter. In verbose mode,\n"
+"   the filter will print out, when it detects a scene change. If\n"
+"   scenechanges go by unnoticed, lower the scene threshold. You can\n"
+"   completly disable chroma processing with the doChroma=0 option.\n"
+"   Here is a sample commandline\n"
+"   -J smartyuv=highq=1:diffmode=2:cubic=1:Blend=1:chromathres=4:threshold=8:doChroma=1\n"
+"* Options\n"
+"  'motionOnly' Show motion areas only (0=off, 1=on) [0]\n"
+"    'diffmode' Motion Detection (0=frame, 1=field, 2=both) [0]\n"
+"   'threshold' Motion Threshold (luma) (0-255) [14]\n"
+" 'chromathres' Motion Threshold (chroma) (0-255) [7]\n"
+"  'scenethres' Threshold for detecting scenechanges (0-255) [31]\n"
+"       'cubic' Do cubic interpolation (0=off 1=on) [1]\n"
+"       'highq' High-Quality processing (motion Map denoising) (0=off 1=on) [1]\n"
+"       'Blend' Blend the frames for deinterlacing (0=off 1=on) [1]\n"
+"    'doChroma' Enable chroma processing (slower but more accurate) (0=off 1=on) [1]\n"
+"     'verbose' Verbose mode (0=off 1=on) [1]\n"
+		, MOD_CAP);
 }
+
 static void Erode_Dilate (uint8_t *_moving, uint8_t *_fmoving, int width, int height)
 {
     int sum, x, y;
@@ -229,7 +194,7 @@ static void Erode_Dilate (uint8_t *_moving, uint8_t *_fmoving, int width, int he
 	    {
 		uint8_t  res[8];
 
-		tc_memcpy(fmoving, moving, 4);
+		ac_memcpy(fmoving, moving, 4);
 
 		m = p;
 
@@ -283,7 +248,7 @@ static void Erode_Dilate (uint8_t *_moving, uint8_t *_fmoving, int width, int he
 	    fmoving += PAD;
 	    moving += PAD;
 	    p += PAD;
-	} else 
+	} else
 #endif
 	{
 	    for (x = 0; x < width; x++)
@@ -345,29 +310,28 @@ static void Erode_Dilate (uint8_t *_moving, uint8_t *_fmoving, int width, int he
 	fmoving += w4;
     }
 }
-static void inline Blendline_c (uint8_t *dst, uint8_t *src, uint8_t *srcminus, uint8_t *srcplus, 
-	                 uint8_t *moving, uint8_t *movingminus, uint8_t *movingplus, const int w, const int scenechange)
+static void inline Blendline_c (uint8_t *dst, uint8_t *src, uint8_t *srcminus, uint8_t *srcplus,
+	                            uint8_t *moving, uint8_t *movingminus, uint8_t *movingplus,
+                                const int w, const int scenechange)
 {
-    int	x=0;
-
+    int x = 0;
     do {
-	if (movingminus[x] | moving[x] | movingplus[x] | scenechange)
-	    /* Blend fields. */
-	    dst[x] = ((src[x]>>1) + (srcminus[x]>>2) + (srcplus[x]>>2)) & 0xff;
-	else
-	{
-	    dst[x] = src[x];
-	}
+        if (movingminus[x] | moving[x] | movingplus[x] | scenechange) {
+            /* Blend fields. */
+            dst[x] = ((src[x]>>1) + (srcminus[x]>>2) + (srcplus[x]>>2)) & 0xff;
+        } else {
+            dst[x] = src[x];
+        }
     } while(++x < w);
 }
 
 // this works fine on OSX too
 #define ABS_u8(a) (((a)^((a)>>7))-((a)>>7))
 
-static void smartyuv_core (char *_src, char *_dst, char *_prev, int _width, int _height, 
-		int _srcpitch, int _dstpitch, 
-		unsigned char *_moving, unsigned char *_fmoving, 
-		unsigned char(*clamp_f)(unsigned char x), int _threshold )
+static void smartyuv_core (char *_src, char *_dst, char *_prev, int _width, int _height,
+                           int _srcpitch, int _dstpitch,
+                           unsigned char *_moving, unsigned char *_fmoving,
+                           yuv_clamp_fn clamp_f, int _threshold )
 {
 	const int		srcpitch = _srcpitch;
 	const int		dstpitch = _dstpitch;
@@ -416,7 +380,6 @@ static void smartyuv_core (char *_src, char *_dst, char *_prev, int _width, int
 	srcplus = src + srcpitch;
 	moving = _moving + w+PAD;
 	prev = _prev + w;
-	//printf("Aligned src %p prev %p moving %p\n", src, prev, moving);
 
 	if (mfd->diffmode == FRAME_ONLY || mfd->diffmode == FRAME_AND_FIELD)
 	{
@@ -468,7 +431,7 @@ static void smartyuv_core (char *_src, char *_dst, char *_prev, int _width, int
 			    // write to moving
 			    movd_r2m(mm0, *moving);
 
-			    tc_memcpy(prev, src, 4);
+			    ac_memcpy(prev, src, 4);
 
 			    src+=4;
 			    prev+=4;
@@ -487,15 +450,6 @@ static void smartyuv_core (char *_src, char *_dst, char *_prev, int _width, int
 		  }  else  // cannot use mmx
 #elif CAN_COMPILE_C_ALTIVEC
 		  if (can_use_altivec) {
-#if 0
-		      typedef union {
-			  vector unsigned char v;
-			  unsigned char e[16];
-		      } uchar_t;
-		      uchar_t res;
-		      //printf("mov: "); for (i=0; i<16;i++) printf("%02x ", res.e[i]&0xff);  printf("\n");
-#endif
-
 		      vector unsigned char vthres;
 		      vector unsigned char shift = vec_splat_u8(7);
 		      unsigned char __attribute__ ((aligned(16))) tdata[16];
@@ -530,18 +484,7 @@ static void smartyuv_core (char *_src, char *_dst, char *_prev, int _width, int
 
 			  moving += PAD;
 		    }
-#if 0
-		    {
-			FILE *f = fopen("mov.dat", "w");
-			printf ("COUNT %d size1 (%d) size2 (%d)\n", count, sizeof (*moving), sizeof (unsigned char));
-			fwrite (_moving, h*w, 1, f);
-			fclose (f);
-			exit(0);
-		    }
-#endif
 
-
-		      
 		  } else
 #endif
 		  {
@@ -561,7 +504,7 @@ static void smartyuv_core (char *_src, char *_dst, char *_prev, int _width, int
 				/* Keep a count of the number of moving pixels for the
 				   scene change detection. */
 				count += *moving++;
-				
+
 			}
 
 			moving += PAD;
@@ -637,7 +580,7 @@ static void smartyuv_core (char *_src, char *_dst, char *_prev, int _width, int
 				// write to moving
 				movd_r2m(mm0, *moving);
 
-				tc_memcpy(prev, src, 4);
+				ac_memcpy(prev, src, 4);
 
 				src+=4;
 				prev+=4;
@@ -698,7 +641,7 @@ static void smartyuv_core (char *_src, char *_dst, char *_prev, int _width, int
 				// write to moving
 				movd_r2m(mm0, *moving);
 
-				tc_memcpy(prev, src, 4);
+				ac_memcpy(prev, src, 4);
 
 				src+=4;
 				prev+=4;
@@ -729,7 +672,7 @@ static void smartyuv_core (char *_src, char *_dst, char *_prev, int _width, int
 		    vthres = vec_ld(0, tdata);
 
 		    count = 0;
-		    //printf ("Align: %p %p %p\n", src, srcminus, prev);
+		    //tc_log_msg(MOD_NAME, "Align: %p %p %p", src, srcminus, prev);
 		    for (y = 1; y < hminus1; y++)
 		    {
 			if (y & 1) { // odd lines
@@ -773,7 +716,7 @@ static void smartyuv_core (char *_src, char *_dst, char *_prev, int _width, int
 				p0 = vec_sub (vec_max (luma, p0), vec_min (luma, p0));
 				p1 = vec_sub (vec_max (luma, p1), vec_min (luma, p1));
 				vmov = vec_and(
-					(vector unsigned char)vec_cmpgt(p0, vthres), 
+					(vector unsigned char)vec_cmpgt(p0, vthres),
 					(vector unsigned char)vec_cmpgt(p1, vthres));
 
 				// FF -> 01
@@ -795,7 +738,7 @@ static void smartyuv_core (char *_src, char *_dst, char *_prev, int _width, int
 
 		    } // height
 
-		    printf ("COUNT %d|\n", count);
+		    tc_log_msg(MOD_NAME, "COUNT %d|", count);
 
 		  } else
 #endif
@@ -804,7 +747,7 @@ static void smartyuv_core (char *_src, char *_dst, char *_prev, int _width, int
 		    for (y = 1; y < hminus1; y++)
 		    {
 			x = 0;
-			if (y & 1) { 
+			if (y & 1) {
 
 			    do {
 
@@ -837,7 +780,6 @@ static void smartyuv_core (char *_src, char *_dst, char *_prev, int _width, int
 			moving += PAD;
 			srcminus += srcpitch;
 		    }
-		    //printf ("XXXCOUNT %d|\n", count);
 		  }
 		}
 
@@ -845,10 +787,10 @@ static void smartyuv_core (char *_src, char *_dst, char *_prev, int _width, int
 		if ((100L * count) / (h * w) >= mfd->scenethreshold) scenechange = 1;
 		else scenechange = 0;
 
-		if (scenechange && mfd->verbose) 
-		    printf("[%s] Scenechange at %6d (%6ld moving pixels)\n", MOD_NAME, counter, count);
+		if (scenechange && mfd->verbose)
+		    tc_log_info(MOD_NAME, "Scenechange at %6d (%6ld moving pixels)", counter, count);
 		/*
-		printf("Frame (%04d) count (%8ld) sc (%d) calc (%02ld)\n", 
+		tc_log_msg(MOD_NAME, "Frame (%04d) count (%8ld) sc (%d) calc (%02ld)",
 				counter, count, scenechange, (100 * count) / (h * w));
 				*/
 
@@ -863,7 +805,7 @@ static void smartyuv_core (char *_src, char *_dst, char *_prev, int _width, int
 		    Erode_Dilate(_moving, _fmoving, w, h);
 
 		    //rdtscll(after);
-		    //printf("%6d : %8lld\n", count, after-before);
+		    //tc_log_msg(MOD_NAME, "%6d : %8lld", count, after-before);
 		}
 	}
 	if (mfd->diffmode == FIELD_ONLY) {
@@ -920,7 +862,7 @@ static void smartyuv_core (char *_src, char *_dst, char *_prev, int _width, int
 				{
 					if (!((_moving + y * (w+PAD))[x]))
 					{
-						fmoving[x] = 0;	
+						fmoving[x] = 0;
 						continue;
 					}
 					xlo = x - Nover2; if (xlo < 0) xlo = 0;
@@ -955,7 +897,7 @@ static void smartyuv_core (char *_src, char *_dst, char *_prev, int _width, int
 				{
 					if (!((_fmoving + y * (w+PAD))[x]))
 					{
-						moving[x] = 0;	
+						moving[x] = 0;
 						continue;
 					}
 					xlo = x - Nover2; if (xlo < 0) xlo = 0;
@@ -973,7 +915,7 @@ static void smartyuv_core (char *_src, char *_dst, char *_prev, int _width, int
 					}
 				}
 				moving += (w+PAD);
-			}		
+			}
 		}
 	}
 
@@ -985,7 +927,7 @@ static void smartyuv_core (char *_src, char *_dst, char *_prev, int _width, int
 	src = src_buf;
 	dst = dst_buf;
 
-	tc_memcpy(dst, src, w);
+	ac_memcpy(dst, src, w);
 	src = src_buf + srcpitch;
 	srcminus = src - srcpitch;
 	srcplus = src + srcpitch;
@@ -1015,7 +957,7 @@ static void smartyuv_core (char *_src, char *_dst, char *_prev, int _width, int
 			if (!(movingminus[x] | moving[x] | movingplus[x]) && !scenechange)
 			    dst[x] = (clamp_f==clamp_Y)?BLACK_BYTE_Y:BLACK_BYTE_UV;
 			else
-			{	
+			{
 			    /* Blend fields. */
 			    dst[x] = (((src[x]&0xff)>>1) + ((srcminus[x]&0xff)>>2) + ((srcplus[x]&0xff)>>2))&0xff;
 			}
@@ -1036,17 +978,7 @@ static void smartyuv_core (char *_src, char *_dst, char *_prev, int _width, int
 				rn =  (srcplus[x]) & 0xff;
 				rnn = (srcplusplus[x]) & 0xff;
 				R = (5 * (rp + rn) - (rpp + rnn)) >> 3;
-				/*
-				   if (R>240) R = 240;
-				   else if (R<16) R=16;
-				   */
-
-                                /* handle over- and underflow */
-                                if (R < 0)
-                                    R = 0;
-                                else if (R > 255)
-                                    R = 255;
-				dst[x] = clamp_f(R & 0xff)&0xff;
+				dst[x] = clamp_f(R);
 			    }
 			    else
 			    {
@@ -1078,7 +1010,7 @@ static void smartyuv_core (char *_src, char *_dst, char *_prev, int _width, int
 		movingplus += (w+PAD);
 	    }
 	    // The last line gets a free ride.
-	    tc_memcpy(dst, src, w);
+	    ac_memcpy(dst, src, w);
 
 	    if (clamp_f == clamp_Y)
 		counter++;
@@ -1086,7 +1018,7 @@ static void smartyuv_core (char *_src, char *_dst, char *_prev, int _width, int
 	    return;
 
 	}
-	
+
 	if (mfd->Blend)
 	{
 	    // linear blend, see Blendline_c for a plainC version
@@ -1125,8 +1057,8 @@ static void smartyuv_core (char *_src, char *_dst, char *_prev, int _width, int
 
 		    pcmpeqw_r2r(mm5, mm5);  // make all ff's (recycle mm5)
 		    psubb_r2r  (mm0, mm5);  // inverse mask
-		    pand_r2r   (mm0, mm7); 
-		    pand_r2r   (mm5, mm1); 
+		    pand_r2r   (mm0, mm7);
+		    pand_r2r   (mm5, mm1);
 		    psrlw_i2r  (1,   mm7);
 
 		    pand_r2r   (mm4, mm7);  // clear highest bit
@@ -1192,7 +1124,7 @@ static void smartyuv_core (char *_src, char *_dst, char *_prev, int _width, int
 
 
 
-	      } else 
+	      } else
 #endif
 	      {
 		Blendline_c (dst, src, srcminus, srcplus, moving, movingminus, movingplus, w, scenechange);
@@ -1227,14 +1159,9 @@ static void smartyuv_core (char *_src, char *_dst, char *_prev, int _width, int
 		    if (movingminus[x] | moving[x] | movingplus[x] | scenechange)
 			if (cubic & (y > 2) & (y < hminus3))
 			{
-			    R = (5 * ((srcminus[x] & 0xff) + (srcplus[x] & 0xff)) 
+			    R = (5 * ((srcminus[x] & 0xff) + (srcplus[x] & 0xff))
 				    - ((srcminusminus[x] & 0xff) + (srcplusplus[x] & 0xff))) >> 3;
-                            /* handle over- and underflow */
-                            if (R < 0)
-                                R = 0;
-                            else if (R > 255)
-                                R = 255;
-			    dst[x] = clamp_f(R & 0xff)&0xff;
+			    dst[x] = clamp_f(R);
 			}
 			else
 			{
@@ -1249,7 +1176,7 @@ static void smartyuv_core (char *_src, char *_dst, char *_prev, int _width, int
 	    else
 	    {
 		// Even line; pass it through.
-		tc_memcpy(dst, src, w);
+		ac_memcpy(dst, src, w);
 	    }
 	    src +=  srcpitch;
 	    srcminus += srcpitch;
@@ -1268,15 +1195,16 @@ static void smartyuv_core (char *_src, char *_dst, char *_prev, int _width, int
 	}
 
 	// The last line gets a free ride.
-	tc_memcpy(dst, src, w);
+	ac_memcpy(dst, src, w);
 	if (clamp_f == clamp_Y)
 	    counter++;
 
 	return;
 }
 
-int tc_filter(vframe_list_t *ptr, char *options)
+int tc_filter(frame_list_t *ptr_, char *options)
 {
+  vframe_list_t *ptr = (vframe_list_t *)ptr_;
 
   //----------------------------------
   //
@@ -1289,18 +1217,17 @@ int tc_filter(vframe_list_t *ptr, char *options)
 
 	unsigned int width, height;
 	int msize;
-    
-	if((vob = tc_get_vob())==NULL) return(-1);
-    
 
-	mfd = (MyFilterData *) malloc(sizeof(MyFilterData));
+	if((vob = tc_get_vob())==NULL) return(-1);
+
+
+	mfd = tc_zalloc(sizeof(MyFilterData));
 
 	if (!mfd) {
-		fprintf(stderr, "No memory!\n"); return (-1);
+		tc_log_error(MOD_NAME, "No memory!");
+	        return (-1);
 	}
 
-	memset (mfd, 0, sizeof(MyFilterData));
-
 	width  = vob->im_v_width;
 	height = vob->im_v_height;
 
@@ -1318,13 +1245,13 @@ int tc_filter(vframe_list_t *ptr, char *options)
 	mfd->verbose        = 0;
 
 	if (mfd->codec != CODEC_YUV) {
-	    tc_warn ("[%s] This filter is only capable of YUV mode", MOD_NAME);
+	    tc_log_error (MOD_NAME, "This filter is only capable of YUV mode");
 	    return -1;
 	}
 
 	if (options != NULL) {
-    
-	  if(verbose) printf("[%s] options=%s\n", MOD_NAME, options);
+
+	  if(verbose) tc_log_info(MOD_NAME, "options=%s", options);
 
 	  optstr_get (options, "motionOnly",     "%d",  &mfd->motionOnly     );
 	  optstr_get (options, "threshold",      "%d",  &mfd->threshold      );
@@ -1337,52 +1264,44 @@ int tc_filter(vframe_list_t *ptr, char *options)
 	  optstr_get (options, "doChroma",       "%d",  &mfd->doChroma       );
 	  optstr_get (options, "verbose",        "%d",  &mfd->verbose        );
 
-	  if (optstr_get (options, "help", "") >= 0) {
+	  if (optstr_lookup (options, "help") != NULL) {
 		  help_optstr();
 	  }
 	}
 
 	if (verbose > 1) {
 
-	  printf (" Smart YUV Deinterlacer Test Filter Settings (%dx%d):\n", width, height);
-	  printf ("        motionOnly = %d\n", mfd->motionOnly);
-	  printf ("          diffmode = %d\n", mfd->diffmode);
-	  printf ("         threshold = %d\n", mfd->threshold);
-	  printf ("       chromathres = %d\n", mfd->chromathres);
-	  printf ("        scenethres = %d\n", mfd->scenethreshold);
-	  printf ("             cubic = %d\n", mfd->cubic);
-	  printf ("             highq = %d\n", mfd->highq);
-	  printf ("             Blend = %d\n", mfd->Blend);
-	  printf ("          doChroma = %d\n", mfd->doChroma);
-	  printf ("           verbose = %d\n", mfd->verbose);
+	  tc_log_info (MOD_NAME, " Smart YUV Deinterlacer Test Filter Settings (%dx%d):", width, height);
+	  tc_log_info (MOD_NAME, "        motionOnly = %d", mfd->motionOnly);
+	  tc_log_info (MOD_NAME, "          diffmode = %d", mfd->diffmode);
+	  tc_log_info (MOD_NAME, "         threshold = %d", mfd->threshold);
+	  tc_log_info (MOD_NAME, "       chromathres = %d", mfd->chromathres);
+	  tc_log_info (MOD_NAME, "        scenethres = %d", mfd->scenethreshold);
+	  tc_log_info (MOD_NAME, "             cubic = %d", mfd->cubic);
+	  tc_log_info (MOD_NAME, "             highq = %d", mfd->highq);
+	  tc_log_info (MOD_NAME, "             Blend = %d", mfd->Blend);
+	  tc_log_info (MOD_NAME, "          doChroma = %d", mfd->doChroma);
+	  tc_log_info (MOD_NAME, "           verbose = %d", mfd->verbose);
 	}
 
 	/* fetch memory */
 
-
-
-	mfd->buf =  bufalloc (width*height*3, mfd->Rbuf);
-	mfd->prevFrame =  bufalloc (width*height*3, mfd->RprevFrame);
+	mfd->buf =  tc_bufalloc (width*height*3);
+	mfd->prevFrame =  tc_bufalloc (width*height*3);
 
 	msize = width*height + 4*(width+PAD) + PAD*height;
-	mfd->movingY = (unsigned char *) bufalloc(sizeof(unsigned char)*msize, 
-		(char *)mfd->RmovingY);
-	mfd->fmovingY = (unsigned char *) bufalloc(sizeof(unsigned char)*msize,
-		(char *)mfd->RfmovingY);
+	mfd->movingY = (unsigned char *) tc_bufalloc(sizeof(unsigned char)*msize);
+	mfd->fmovingY = (unsigned char *) tc_bufalloc(sizeof(unsigned char)*msize);
 
 	msize = width*height/4 + 4*(width+PAD) + PAD*height;
-	mfd->movingU  = (unsigned char *) bufalloc(sizeof(unsigned char)*msize,
-		(char *)mfd->RmovingU);
-	mfd->movingV  = (unsigned char *) bufalloc(sizeof(unsigned char)*msize,
-		(char *)mfd->RmovingV);
-	mfd->fmovingU = (unsigned char *) bufalloc(sizeof(unsigned char)*msize,
-		(char *)mfd->RfmovingU);
-	mfd->fmovingV = (unsigned char *) bufalloc(sizeof(unsigned char)*msize,
-		(char *)mfd->RfmovingV);
+	mfd->movingU  = (unsigned char *) tc_bufalloc(sizeof(unsigned char)*msize);
+	mfd->movingV  = (unsigned char *) tc_bufalloc(sizeof(unsigned char)*msize);
+	mfd->fmovingU = (unsigned char *) tc_bufalloc(sizeof(unsigned char)*msize);
+	mfd->fmovingV = (unsigned char *) tc_bufalloc(sizeof(unsigned char)*msize);
 
-	if ( !mfd->movingY || !mfd->movingU || !mfd->movingV || !mfd->fmovingY || 
+	if ( !mfd->movingY || !mfd->movingU || !mfd->movingV || !mfd->fmovingY ||
 	      !mfd->fmovingU || !mfd->fmovingV || !mfd->buf || !mfd->prevFrame) {
-	    fprintf (stderr, "[%s] Memory allocation error\n", MOD_NAME);
+	    tc_log_msg(MOD_NAME, "Memory allocation error");
 	    return -1;
 	}
 
@@ -1410,7 +1329,7 @@ int tc_filter(vframe_list_t *ptr, char *options)
 	// This is also the reason for the w+4's all over the place.
 	//
 	// This gives an speedup factor in erode+denoise of about 3.
-	// 
+	//
 	// A lot of brain went into the optimisations, here are some numbers of
 	// the separate steps. Note, to get these numbers I used the rdtsc
 	// instruction to read the CPU cycle counter in seperate programms:
@@ -1438,43 +1357,43 @@ int tc_filter(vframe_list_t *ptr, char *options)
 
 	// filter init ok.
 
-	if(verbose) printf("[%s] "
+	if(verbose) tc_log_info(MOD_NAME,
 #ifdef HAVE_ASM_MMX
 		"(MMX) "
 #endif
 #ifdef CAN_COMPILE_C_ALTIVEC
 		"(ALTIVEC) "
 #endif
-		"%s %s\n", MOD_NAME, MOD_VERSION, MOD_CAP);
+		"%s %s", MOD_VERSION, MOD_CAP);
 
 	return 0;
 
   } /* TC_FILTER_INIT */
-	
+
 
   if(ptr->tag & TC_FILTER_GET_CONFIG) {
       char buf[255];
       optstr_filter_desc (options, MOD_NAME, MOD_CAP, MOD_VERSION, MOD_AUTHOR, "VYE", "1");
 
-      snprintf (buf, sizeof(buf), "%d", mfd->motionOnly);
+      tc_snprintf (buf, sizeof(buf), "%d", mfd->motionOnly);
       optstr_param (options, "motionOnly", "Show motion areas only, blacking out static areas" ,"%d", buf, "0", "1");
-      snprintf (buf, sizeof(buf), "%d", mfd->diffmode);
+      tc_snprintf (buf, sizeof(buf), "%d", mfd->diffmode);
       optstr_param (options, "diffmode", "Motion Detection (0=frame, 1=field, 2=both)", "%d", buf, "0", "2" );
-      snprintf (buf, sizeof(buf), "%d", mfd->threshold);
+      tc_snprintf (buf, sizeof(buf), "%d", mfd->threshold);
       optstr_param (options, "threshold", "Motion Threshold (luma)", "%d", buf, "0", "255" );
-      snprintf (buf, sizeof(buf), "%d", mfd->chromathres);
+      tc_snprintf (buf, sizeof(buf), "%d", mfd->chromathres);
       optstr_param (options, "chromathres", "Motion Threshold (chroma)", "%d", buf, "0", "255" );
-      snprintf (buf, sizeof(buf), "%d", mfd->scenethreshold);
+      tc_snprintf (buf, sizeof(buf), "%d", mfd->scenethreshold);
       optstr_param (options, "scenethres", "Threshold for detecting scenechanges", "%d", buf, "0", "255" );
-      snprintf (buf, sizeof(buf), "%d", mfd->highq);
+      tc_snprintf (buf, sizeof(buf), "%d", mfd->highq);
       optstr_param (options, "highq", "High-Quality processing (motion Map denoising)", "%d", buf, "0", "1" );
-      snprintf (buf, sizeof(buf), "%d", mfd->cubic);
+      tc_snprintf (buf, sizeof(buf), "%d", mfd->cubic);
       optstr_param (options, "cubic", "Do cubic interpolation", "%d", buf, "0", "1" );
-      snprintf (buf, sizeof(buf), "%d", mfd->Blend);
+      tc_snprintf (buf, sizeof(buf), "%d", mfd->Blend);
       optstr_param (options, "Blend", "Blend the frames for deinterlacing", "%d", buf, "0", "1" );
-      snprintf (buf, sizeof(buf), "%d", mfd->doChroma);
+      tc_snprintf (buf, sizeof(buf), "%d", mfd->doChroma);
       optstr_param (options, "doChroma", "Enable chroma processing (slower but more accurate)", "%d", buf, "0", "1" );
-      snprintf (buf, sizeof(buf), "%d", mfd->verbose);
+      tc_snprintf (buf, sizeof(buf), "%d", mfd->verbose);
       optstr_param (options, "verbose", "Verbose mode", "%d", buf, "0", "1" );
 
       return (0);
@@ -1484,29 +1403,25 @@ int tc_filter(vframe_list_t *ptr, char *options)
 
 	if (!mfd)
 		return 0;
-	
-	if (mfd->Rbuf)
-	    free(mfd->Rbuf);
+
+	tc_buffree (mfd->buf);
 	mfd->buf = NULL;
-	mfd->Rbuf = NULL;
 
-	if (mfd->RprevFrame)
-	    free(mfd->RprevFrame);
+	tc_buffree (mfd->prevFrame);
 	mfd->prevFrame = NULL;
-	mfd->RprevFrame = NULL;
 
-	if (mfd->RmovingY) free(mfd->RmovingY); mfd->RmovingY = NULL; 
+	tc_buffree (mfd->movingY);
 	mfd->movingY = NULL;
-	if (mfd->RmovingU) free(mfd->RmovingU); mfd->RmovingU = NULL;
+	tc_buffree (mfd->movingU);
 	mfd->movingU = NULL;
-	if (mfd->RmovingV) free(mfd->RmovingV); mfd->RmovingV = NULL;
+	tc_buffree (mfd->movingV);
 	mfd->movingV = NULL;
 
-	if (mfd->RfmovingY) free(mfd->RfmovingY); mfd->RfmovingY = NULL;
+	tc_buffree (mfd->fmovingY);
 	mfd->fmovingY = NULL;
-	if (mfd->RfmovingU) free(mfd->RfmovingU); mfd->RfmovingU = NULL;
+	tc_buffree (mfd->fmovingU);
 	mfd->fmovingU = NULL;
-	if (mfd->RfmovingV) free(mfd->RfmovingV); mfd->RfmovingV = NULL;
+	tc_buffree (mfd->fmovingV);
 	mfd->fmovingV = NULL;
 
 	if (mfd)
@@ -1519,8 +1434,8 @@ int tc_filter(vframe_list_t *ptr, char *options)
 ///////////////////////////////////////////////////////////////////////////
 
   //if(ptr->tag & TC_PRE_S_PROCESS && ptr->tag & TC_VIDEO && !(ptr->attributes & TC_FRAME_IS_SKIPPED)) {
-  if(ptr->tag & TC_PRE_PROCESS && ptr->tag & TC_VIDEO && !(ptr->attributes & TC_FRAME_IS_SKIPPED)) {
-	  
+  if(ptr->tag & TC_PRE_M_PROCESS && ptr->tag & TC_VIDEO && !(ptr->attributes & TC_FRAME_IS_SKIPPED)) {
+
 	  int U  = ptr->v_width*ptr->v_height;
 	  int V  = ptr->v_width*ptr->v_height*5/4;
 	  int w2 = ptr->v_width/2;
@@ -1534,7 +1449,7 @@ int tc_filter(vframe_list_t *ptr, char *options)
 	  */
 
 
-	  smartyuv_core(ptr->video_buf, mfd->buf, mfd->prevFrame, 
+	  smartyuv_core(ptr->video_buf, mfd->buf, mfd->prevFrame,
 		        ptr->v_width, ptr->v_height, ptr->v_width, ptr->v_width,
 		        mfd->movingY+off, mfd->fmovingY+off, clamp_Y, mfd->threshold);
 
@@ -1550,16 +1465,16 @@ int tc_filter(vframe_list_t *ptr, char *options)
 	      /*
 	      */
 
-	      smartyuv_core(ptr->video_buf+U, mfd->buf+U, mfd->prevFrame+U, 
+	      smartyuv_core(ptr->video_buf+U, mfd->buf+U, mfd->prevFrame+U,
 			  w2, h2, w2, w2,
 			  mfd->movingU+off, mfd->fmovingU+off, clamp_UV, mfd->chromathres);
 
-	      smartyuv_core(ptr->video_buf+V, mfd->buf+V, mfd->prevFrame+V, 
+	      smartyuv_core(ptr->video_buf+V, mfd->buf+V, mfd->prevFrame+V,
 			  w2, h2, w2, w2,
 			  mfd->movingV+off, mfd->fmovingV+off, clamp_UV, mfd->chromathres);
 	  } else {
 	      //pass through
-	      tc_memcpy(mfd->buf+U, ptr->video_buf+U, ptr->v_width*ptr->v_height/2);
+	      ac_memcpy(mfd->buf+U, ptr->video_buf+U, ptr->v_width*ptr->v_height/2);
 	      //memset(mfd->buf+U, BLACK_BYTE_UV, ptr->v_width*ptr->v_height/2);
 	  }
 
@@ -1568,7 +1483,7 @@ int tc_filter(vframe_list_t *ptr, char *options)
 	  memset(mfd->buf+U, BLACK_BYTE_UV, ptr->v_width*ptr->v_height/2);
 			  */
 
-	  tc_memcpy (ptr->video_buf, mfd->buf, ptr->video_size);
+	  ac_memcpy (ptr->video_buf, mfd->buf, ptr->video_size);
 
 	  return 0;
   }
