@@ -1,23 +1,23 @@
 /*
  *  filter_pv.c
  *
- *  Copyright (C) Thomas streich - October 2002
+ *  Copyright (C) Thomas Oestreich - October 2002
  *
  *  This file is part of transcode, a video stream processing tool
- *      
+ *
  *  transcode is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 2, or (at your option)
  *  any later version.
- *   
+ *
  *  transcode is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
- *   
+ *
  *  You should have received a copy of the GNU General Public License
  *  along with GNU Make; see the file COPYING.  If not, write to
- *  the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA. 
+ *  the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
  *
  */
 
@@ -28,14 +28,15 @@
 
 #include "transcode.h"
 #include "filter.h"
-#include "optstr.h"
+#include "libtc/optstr.h"
+#include "libtcvideo/tcvideo.h"
 
 #include "video_trans.h"
 
 #ifdef HAVE_DLFCN_H
 #include <dlfcn.h>
 #else
-# ifdef SYSTEM_DARWIN
+# ifdef OS_DARWIN
 #  include "libdldarwin/dlfcn.h"
 # endif
 #endif
@@ -63,17 +64,21 @@ static int rows=20;
 static char buffer[128];
 static int size=0;
 static int use_secondary_buffer=0;
+static ImageFormat srcfmt = IMG_NONE, destfmt = IMG_NONE;
 
 static int xv_init_ok=0;
 
 static int preview_delay=0;
 static int preview_skip=0, preview_skip_num=25;
+static int preview_xv_port=0;
 static char *undo_buffer = NULL;
 static char *run_buffer[2] = {NULL, NULL};
 static char *process_buffer[3] = {NULL, NULL, NULL};
 
 static int process_ctr_cur=0;
 
+static TCVHandle tcvhandle;
+
 
 /* global variables */
 
@@ -82,21 +87,21 @@ static xv_player_t *xv_player = NULL;
 
 #define ONE_SECOND 1000000 // in units of usec
 
-void inc_preview_delay()
+void inc_preview_delay(void)
 {
   preview_delay+=ONE_SECOND/10;
   if(preview_delay>ONE_SECOND) preview_delay=ONE_SECOND;
 }
 
-void dec_preview_delay()
+void dec_preview_delay(void)
 {
   preview_delay-=ONE_SECOND/10;
   if(preview_delay<0) preview_delay=0;
 }
 
-void preview_toggle_skip()
+void preview_toggle_skip(void)
 {
-  preview_skip = (preview_skip>0) ? 0: preview_skip_num; 
+  preview_skip = (preview_skip>0) ? 0: preview_skip_num;
 }
 
 /*-------------------------------------------------
@@ -105,32 +110,9 @@ void preview_toggle_skip()
  *
  *-------------------------------------------------*/
 
-char * preview_alloc_align_buffer(size_t size)
+int tc_filter(frame_list_t *ptr_, char *options)
 {
-#ifdef HAVE_GETPAGESIZE
-   long buffer_align=getpagesize();
-#else
-   long buffer_align=0;
-#endif
-   char *buf = malloc(size + buffer_align);
-
-   long adjust;
-
-   if (buf == NULL) {
-       fprintf(stderr, "(%s) out of memory", __FILE__);
-   }
-   
-   adjust = buffer_align - ((long) buf) % buffer_align;
-
-   if (adjust == buffer_align)
-      adjust = 0;
-
-   return (buf + adjust);
-}
-
-int tc_filter(vframe_list_t *ptr, char *options)
-{
-
+  vframe_list_t *ptr = (vframe_list_t *)ptr_;
   vob_t *vob=NULL;
 
   int pre=0, vid=0;
@@ -140,6 +122,7 @@ int tc_filter(vframe_list_t *ptr, char *options)
       optstr_param (options, "cache", "Number of raw frames to cache for seeking",  "%d", "15", "15", "255");
       optstr_param (options, "skip", "display only every Nth frame",  "%d", "0", "0", "255");
       optstr_param (options, "fullscreen", "Display in fullscreen mode","", "0");
+      optstr_param (options, "port", "force Xv port","%d", "0", "0", "255");
   }
 
   //----------------------------------
@@ -151,17 +134,17 @@ int tc_filter(vframe_list_t *ptr, char *options)
   if(ptr->tag & TC_FILTER_INIT) {
 
     if((vob = tc_get_vob())==NULL) return(-1);
-    
+
     // filter init ok.
-    
-    if(verbose) printf("[%s] %s %s\n", MOD_NAME, MOD_VERSION, MOD_CAP);
-    
+
+    if(verbose) tc_log_info(MOD_NAME, "%s %s", MOD_VERSION, MOD_CAP);
+
     if (options != NULL) {
-      
-      if(verbose) printf("[%s] options=%s\n", MOD_NAME, options);
-      
+
+      if(verbose) tc_log_info(MOD_NAME, "options=%s", options);
+
       optstr_get (options, "cache", "%d", &cache_num);
-      
+
       //adjust for small buffers
       if(cache_num && cache_num<15) {
 	cache_num=15;
@@ -173,56 +156,69 @@ int tc_filter(vframe_list_t *ptr, char *options)
 
     }
 
-    if(cache_num<0) printf("[%s] invalid cache number - exit\n", MOD_NAME);
-    if(preview_skip_num<0) printf("[%s] invalid number of frames to skip - exit\n", MOD_NAME);
+    if(cache_num<0) tc_log_warn(MOD_NAME, "invalid cache number - exit");
+    if(preview_skip_num<0) tc_log_warn(MOD_NAME, "invalid number of frames to skip - exit");
+
+    tc_snprintf(buffer, sizeof(buffer), "%s-%s", PACKAGE, VERSION);
 
-    snprintf(buffer, sizeof(buffer), "%s-%s", PACKAGE, VERSION);
-    
     if(xv_player != NULL) return(-1);
     if(!(xv_player = xv_player_new())) return(-1);
 
 
     if (options != NULL) {
-      if(optstr_get (options, "fullscreen", "") == 0)
+      if(optstr_lookup(options, "fullscreen") != NULL)
         xv_player->display->full_screen = 1;
+      optstr_get (options, "port", "%d", &preview_xv_port);
+      if(preview_xv_port != 0) {
+        tc_log_info(MOD_NAME, "forced Xv port: %d", preview_xv_port);
+        xv_player->display->arg_xv_port = preview_xv_port;
+      }
     }
 
 
     //init filter
-    
-    w = tc_x_preview;
-    h = tc_y_preview;
+
+    w = vob->ex_v_width;
+    h = vob->ex_v_height;
 
     size = w*h* 3/2;
-    
-    if(verbose) printf("[%s] preview window %dx%d\n", MOD_NAME, w, h);
-    
+
+    if(verbose) tc_log_info(MOD_NAME, "preview window %dx%d", w, h);
+
+    tcvhandle = tcv_init();
+    if (!tcvhandle) {
+      tc_log_error(MOD_NAME, "tcv_init() failed");
+      return -1;
+    }
+
     switch(vob->im_v_codec) {
-      
+
     case CODEC_YUV422:
-      
-      if(xv_display_init(xv_player->display, 0, NULL, 
+
+      if(xv_display_init(xv_player->display, 0, NULL,
 			 w, h, buffer, buffer, 1)<0) return(-1);
-			 size = w*h*2;
+      size = w*h*2;
+      srcfmt = IMG_YUV422P;
+      destfmt = IMG_YUY2;
 
       break;
-    
+
     case CODEC_YUV:
-      
-      if(xv_display_init(xv_player->display, 0, NULL, 
+
+      if(xv_display_init(xv_player->display, 0, NULL,
 			 w, h, buffer, buffer, 0)<0) return(-1);
 
       break;
-    
+
     case CODEC_RAW_YUV:
-    
-      if(xv_display_init(xv_player->display, 0, NULL, 
+
+      if(xv_display_init(xv_player->display, 0, NULL,
 			  w, h, buffer, buffer, 0)<0) return(-1);
       use_secondary_buffer=1;
       break;
-      
+
     default:
-      fprintf(stderr, "[%s] non-YUV codecs not supported for this preview plug-in\n", MOD_NAME);
+      tc_log_error(MOD_NAME, "non-YUV codecs not supported for this preview plug-in");
       return(-1);
     }
 
@@ -231,41 +227,45 @@ int tc_filter(vframe_list_t *ptr, char *options)
     if (cache_num) {
       if(preview_cache_init()<0) return(-1);
 
-      if ((undo_buffer = preview_alloc_align_buffer(SIZE_RGB_FRAME)) == NULL)
+      /* FIXME: these are never freed! */
+      if ((undo_buffer = tc_bufalloc(SIZE_RGB_FRAME)) == NULL)
 	  return (-1);
-      if ((run_buffer[0] = preview_alloc_align_buffer (SIZE_RGB_FRAME)) == NULL)
+      if ((run_buffer[0] = tc_bufalloc (SIZE_RGB_FRAME)) == NULL)
 	  return (-1);
-      if ((run_buffer[1] = preview_alloc_align_buffer (SIZE_RGB_FRAME)) == NULL)
+      if ((run_buffer[1] = tc_bufalloc (SIZE_RGB_FRAME)) == NULL)
 	  return (-1);
-      if ((process_buffer[0] = preview_alloc_align_buffer (SIZE_RGB_FRAME)) == NULL)
+      if ((process_buffer[0] = tc_bufalloc (SIZE_RGB_FRAME)) == NULL)
 	  return (-1);
-      if ((process_buffer[1] = preview_alloc_align_buffer (SIZE_RGB_FRAME)) == NULL)
+      if ((process_buffer[1] = tc_bufalloc (SIZE_RGB_FRAME)) == NULL)
 	  return (-1);
-      if ((process_buffer[2] = preview_alloc_align_buffer (SIZE_RGB_FRAME)) == NULL)
+      if ((process_buffer[2] = tc_bufalloc (SIZE_RGB_FRAME)) == NULL)
 	  return (-1);
-      
+
     }
 
     xv_init_ok=1;
 
     return(0);
   }
-  
+
   //----------------------------------
   //
   // filter close
   //
   //----------------------------------
-  
+
   if(ptr->tag & TC_FILTER_CLOSE) {
 
     if(!xv_init_ok) return(0);
 
     if(size) xv_display_exit(xv_player->display);
 
+    tcv_free(tcvhandle);
+    tcvhandle = 0;
+
     return(0);
   }
-  
+
   //----------------------------------
   //
   // filter frame routine
@@ -275,8 +275,8 @@ int tc_filter(vframe_list_t *ptr, char *options)
   // tag variable indicates, if we are called before
   // transcodes internal video/audo frame processing routines
   // or after and determines video/audio context
-  
-  if(verbose & TC_STATS) printf("[%s] %s/%s %s %s\n", MOD_NAME, vob->mod_path, MOD_NAME, MOD_VERSION, MOD_CAP);
+
+  if(verbose & TC_STATS) tc_log_info(MOD_NAME, "%s/%s %s %s", vob->mod_path, MOD_NAME, MOD_VERSION, MOD_CAP);
 
   //we do nothing if not properly initialized
   if(!xv_init_ok) return(0);
@@ -284,59 +284,67 @@ int tc_filter(vframe_list_t *ptr, char *options)
   // tag variable indicates, if we are called before
   // transcodes internal video/audo frame processing routines
   // or after and determines video/audio context
-  
-  pre = (ptr->tag & TC_POST_S_PROCESS)? 1:0;
+
+  pre = (ptr->tag & TC_PREVIEW)? 1:0;
   vid = (ptr->tag & TC_VIDEO)? 1:0;
-  
-  if( (ptr->tag & TC_PRE_PROCESS) && vid && cache_enabled) {
+
+  if( (ptr->tag & TC_PRE_M_PROCESS) && vid && cache_enabled) {
       process_ctr_cur = (process_ctr_cur+1)%3;
-      tc_memcpy (process_buffer[process_ctr_cur], ptr->video_buf, ptr->video_size);
+      ac_memcpy (process_buffer[process_ctr_cur], ptr->video_buf, ptr->video_size);
       return 0;
   }
   if(pre && vid) {
-    
+
     if(preview_skip && (ptr->id % preview_skip_num)) return(0);
-    
+
     if(!xv_player->display->dontdraw) {
-      
+
       //0.6.2 (secondaray buffer for pass-through mode)
-      (use_secondary_buffer) ? tc_memcpy(xv_player->display->pixels[0], (char*) ptr->video_buf2, size) : tc_memcpy(xv_player->display->pixels[0], (char*) ptr->video_buf, size); 
-      
+      if (use_secondary_buffer) {
+          ac_memcpy(xv_player->display->pixels[0], ptr->video_buf2, size);
+      } else if (srcfmt != IMG_NONE && destfmt != IMG_NONE) {
+	  tcv_convert(tcvhandle, ptr->video_buf,
+		      (uint8_t *)xv_player->display->pixels,
+		      w, h, srcfmt, destfmt);
+      } else {
+          ac_memcpy(xv_player->display->pixels[0], ptr->video_buf, size);
+      }
+
       //display video frame
       xv_display_show(xv_player->display);
-      
+
       if(cache_enabled) preview_cache_submit(xv_player->display->pixels[0], ptr->id, ptr->attributes);
-      
+
       if(preview_delay) usleep(preview_delay);
 
     } else {
-      
+
       //check only for X11-events
       xv_display_event(xv_player->display);
-    
+
     }//dontdraw=1?
-  
+
   }//correct slot?
-  
+
   return(0);
 }
 
-int preview_cache_init() {
-  
+int preview_cache_init(void) {
+
   //size must be know!
-  
+
   int n;
 
   if((vid_buf_mem = (char *) calloc(cache_num, size))==NULL) {
-    perror("out of memory");
+    tc_log_perror(MOD_NAME, "out of memory");
     return(-1);
   }
-  
+
   if((vid_buf = (char **) calloc(cache_num, sizeof(char *)))==NULL) {
-    perror("out of memory");
+    tc_log_perror(MOD_NAME, "out of memory");
     return(-1);
   }
-  
+
   for (n=0; n<cache_num; ++n) vid_buf[n] = (char *) (vid_buf_mem + n * size);
 
   cache_enabled=1;
@@ -345,19 +353,19 @@ int preview_cache_init() {
 
 }
 
-void preview_cache_submit(char *buf, int id, int flag) {    
+void preview_cache_submit(char *buf, int id, int flag) {
 
   char string[255];
   memset (string, 0, 255);
-  
+
   if(!cache_enabled) return;
 
   cache_ptr = (cache_ptr+1)%cache_num;
-  
-  tc_memcpy((char*) vid_buf[cache_ptr], buf, size);
-  
-  (flag & TC_FRAME_IS_KEYFRAME) ? snprintf(string, sizeof(string), "%u *", id) : snprintf(string, sizeof(string), "%u", id);
-  
+
+  ac_memcpy((char*) vid_buf[cache_ptr], buf, size);
+
+  (flag & TC_FRAME_IS_KEYFRAME) ? tc_snprintf(string, sizeof(string), "%u *", id) : tc_snprintf(string, sizeof(string), "%u", id);
+
   str2img (vid_buf[cache_ptr], string, w, h, cols, rows, 0, 0, CODEC_YUV);
 }
 
@@ -365,32 +373,32 @@ int preview_filter_buffer(int frames_needed)
 {
     int current,i;
 
-    static int this_filter = -1;
-    static vframe_list_t *ptr = NULL; 
+    static int this_filter = 0;
+    static vframe_list_t *ptr = NULL;
     vob_t *vob = tc_get_vob();
 
-    if (ptr == NULL) 
+    if (ptr == NULL)
 	ptr = malloc (sizeof (vframe_list_t));
     memset (ptr, 0, sizeof (vframe_list_t));
 
     if (!cache_enabled) return 0;
 
-    if (this_filter == -1);
-	this_filter = plugin_find_id("pv");
+    if (this_filter == 0)
+	this_filter = tc_filter_find("pv");
 
     for (current = frames_needed, i = 1; current > 0; current--, i++){
 
 #undef NO_PROCESS
 #ifdef NO_PROCESS
-	tc_memcpy (run_buffer[0], (char *)vid_buf[cache_ptr-(current-1)], size);
-	tc_memcpy (run_buffer[1], (char *)vid_buf[cache_ptr-(current-1)], size);
+	ac_memcpy (run_buffer[0], (char *)vid_buf[cache_ptr-(current-1)], size);
+	ac_memcpy (run_buffer[1], (char *)vid_buf[cache_ptr-(current-1)], size);
 #else
-	tc_memcpy (run_buffer[0], process_buffer[(process_ctr_cur+1)%3], SIZE_RGB_FRAME);
-	tc_memcpy (run_buffer[1], process_buffer[(process_ctr_cur+1)%3], SIZE_RGB_FRAME);
+	ac_memcpy (run_buffer[0], process_buffer[(process_ctr_cur+1)%3], SIZE_RGB_FRAME);
+	ac_memcpy (run_buffer[1], process_buffer[(process_ctr_cur+1)%3], SIZE_RGB_FRAME);
 #endif
 
 	if (i == 1) {
-	    tc_memcpy (undo_buffer, (char *)vid_buf[cache_ptr], size);
+	    ac_memcpy (undo_buffer, (char *)vid_buf[cache_ptr], size);
 	}
 
 	ptr->bufid = 1;
@@ -399,16 +407,18 @@ int preview_filter_buffer(int frames_needed)
 	ptr->filter_id = 0;
 	ptr->v_codec = CODEC_YUV;
 	ptr->id  = i; // frame
+#ifdef STATBUFFER
 	ptr->internal_video_buf_0 = run_buffer[0];
 	ptr->internal_video_buf_1 = run_buffer[1];
+#endif /* STATBUFFER */
 
 	// RGB
-	ptr->video_buf_RGB[0]=ptr->internal_video_buf_0;
-	ptr->video_buf_RGB[1]=ptr->internal_video_buf_1;
+	ptr->video_buf_RGB[0]=run_buffer[0];
+	ptr->video_buf_RGB[1]=run_buffer[1];
 
 	//YUV
-	ptr->video_buf_Y[0] = ptr->internal_video_buf_0;
-	ptr->video_buf_Y[1] = ptr->internal_video_buf_1;
+	ptr->video_buf_Y[0] = run_buffer[0];
+	ptr->video_buf_Y[1] = run_buffer[1];
 
 	ptr->video_buf_U[0] = ptr->video_buf_Y[0]
 	    + TC_MAX_V_FRAME_WIDTH * TC_MAX_V_FRAME_HEIGHT;
@@ -421,8 +431,8 @@ int preview_filter_buffer(int frames_needed)
 	    + (TC_MAX_V_FRAME_WIDTH * TC_MAX_V_FRAME_HEIGHT)/4;
 
 	//default pointer
-	ptr->video_buf  = ptr->internal_video_buf_0;
-	ptr->video_buf2 = ptr->internal_video_buf_1;
+	ptr->video_buf  = run_buffer[0];
+	ptr->video_buf2 = run_buffer[1];
 	ptr->free = 1;
 
 #ifdef NO_PROCESS
@@ -437,25 +447,25 @@ int preview_filter_buffer(int frames_needed)
 
 	// we disable this filter (filter_pv), because it does not make sense
 	// to be run in the preview loop
-	plugin_disable_id (this_filter);
+	tc_filter_disable(this_filter);
 
 	// PRE
 	ptr->tag= TC_VIDEO | TC_PRE_S_PROCESS  | TC_PRE_M_PROCESS;
-	process_vid_plugins (ptr);
+	tc_filter_process((frame_list_t *)ptr);
 
 	// CORE
 	process_vid_frame(vob, ptr);
 
 	// POST
 	ptr->tag= TC_VIDEO | TC_POST_S_PROCESS | TC_POST_M_PROCESS;
-	process_vid_plugins (ptr);
+	tc_filter_process((frame_list_t *)ptr);
 
-	plugin_enable_id (this_filter);
-	
-	tc_memcpy (vid_buf[cache_ptr-current+1], ptr->video_buf, size);
+	tc_filter_enable(this_filter);
+
+	ac_memcpy (vid_buf[cache_ptr-current+1], ptr->video_buf, size);
 	preview_cache_draw(0);
 
-	tc_memcpy ((char *)vid_buf[cache_ptr], undo_buffer, size);
+	ac_memcpy ((char *)vid_buf[cache_ptr], undo_buffer, size);
     }
     return 0;
 }
@@ -473,11 +483,11 @@ void preview_filter(void)
     int frames_needed = 1;
     int current=0;
     int i;
-    
+
     if (!cache_enabled) return;
 
     // build commandline
-    snprintf (buf, 1024, 
+    tc_snprintf (buf, 1024,
 	   "xterm -title \"Transcode Filter select\" -e %s/filter_list.awk %s %s &&  cat %s && rm -f %s",
 	   vob->mod_path, vob->mod_path, tmpfile, tmpfile, tmpfile);
     if ((f = popen (buf, "r")) == NULL) {
@@ -503,40 +513,40 @@ void preview_filter(void)
     pclose (f);
 
     if (disable) {
-	filter_handle = plugin_find_id (filter_name);
+	filter_handle = tc_filter_find(filter_name);
 	if (filter_handle == -1) {
 	    // not loaded
-	    return; 
+	    return;
 	} else {
-	    plugin_disable_id(filter_handle);
+	    tc_filter_disable(filter_handle);
 	    goto redisplay_frame;
 	}
     }
-    filter_handle = plugin_get_handle (filter_name);
+    filter_handle = tc_filter_add(filter_name, NULL);
+
+    this_filter  = tc_filter_find("pv");
+    tc_log_msg(MOD_NAME, "this_filter (%d)", this_filter);
 
-    this_filter  = plugin_find_id ("pv");
-    fprintf (stderr, "[%s] this_filter (%d)\n", MOD_NAME, this_filter);
-    
     // we now have a valid ID
-    if ( (config = filter_single_readconf(filter_handle)) == NULL) {
-	fprintf(stderr, "[%s] Filter \"%s\" can not be configured.\n", MOD_NAME, filter_name);
+    if ( (config = tc_filter_get_conf(filter_handle, NULL)) == NULL) {
+	tc_log_warn(MOD_NAME, "Filter \"%s\" can not be configured.", filter_name);
     }
 
     if ((g = fopen(tmpfile, "w")) != NULL) {
 	fputs (config, g);
 	fclose (g);
     } else {
-	fprintf(stderr, "[%s] unable to write to %s.\n", MOD_NAME, tmpfile);
+	tc_log_warn(MOD_NAME, "unable to write to %s.\n", tmpfile);
 	return;
     }
-    
+
     if ((c = strchr (config, '\n'))) {
 	*c = '\0';
 	optstr_frames_needed (config, &frames_needed);
-    } else 
+    } else
 	frames_needed = 1;
-    
-    printf ("XXX optstr_frames_needed:(%d)\n", frames_needed);
+
+    tc_log_msg(MOD_NAME, "XXX optstr_frames_needed:(%d)", frames_needed);
 
 
     free (config);
@@ -544,7 +554,7 @@ void preview_filter(void)
     // recycle
     memset (buf, 0, 1024);
 
-    snprintf (buf, 1024, 
+    tc_snprintf (buf, 1024,
 	  "xterm -title \"Transcode parameters\" -e %s/parse_csv.awk %s %s %s && cat %s && rm -f %s %s",
 	  vob->mod_path, tmpfile, filter_name, infile, infile, tmpfile, infile);
 
@@ -563,22 +573,24 @@ void preview_filter(void)
 
     buf[strlen(buf)-1] = '\0';
 
-    //fprintf(stderr, "XX buf (%s)", buf);
+    //tc_log_msg(MOD_NAME, "XX buf (%s)", buf);
     // XXX
-    if (buf && *buf)
-	filter_single_configure_handle (filter_handle, strchr (buf, '='));
+    if (buf && *buf) {
+	char *s = strchr(buf, '=');
+	tc_filter_configure(filter_handle, s ? s+1 : NULL);
+    }
 
-redisplay_frame: 
+redisplay_frame:
     // logoaway pos=210x136:size=257x175:mode=2
     for (current = frames_needed, i = 1; current > 0; current--, i++){
 
 	vframe_list_t ptr;
 
 	if (!disable)
-	    tc_memcpy (undo_buffer, (char *)vid_buf[cache_ptr], size);
+	    ac_memcpy (undo_buffer, (char *)vid_buf[cache_ptr], size);
 
-	tc_memcpy (run_buffer[0], (char *)vid_buf[cache_ptr-(current-1)], size);
-	tc_memcpy (run_buffer[1], (char *)vid_buf[cache_ptr-(current-1)], size);
+	ac_memcpy (run_buffer[0], (char *)vid_buf[cache_ptr-(current-1)], size);
+	ac_memcpy (run_buffer[1], (char *)vid_buf[cache_ptr-(current-1)], size);
 
 	ptr.bufid = 1;
 	ptr.next = &ptr;
@@ -588,16 +600,18 @@ redisplay_frame:
 	ptr.filter_id = 0;
 	ptr.v_codec = CODEC_YUV;
 	ptr.id  = i; // frame
+#ifdef STATBUFFER	
 	ptr.internal_video_buf_0 = run_buffer[0];
 	ptr.internal_video_buf_1 = run_buffer[1];
+#endif /* STATBUFFER */
 
 	// RGB
-	ptr.video_buf_RGB[0]=ptr.internal_video_buf_0;
-	ptr.video_buf_RGB[1]=ptr.internal_video_buf_1;
+	ptr.video_buf_RGB[0]=run_buffer[0];
+	ptr.video_buf_RGB[1]=run_buffer[1];
 
 	//YUV
-	ptr.video_buf_Y[0] = ptr.internal_video_buf_0;
-	ptr.video_buf_Y[1] = ptr.internal_video_buf_1;
+	ptr.video_buf_Y[0] = run_buffer[0];
+	ptr.video_buf_Y[1] = run_buffer[1];
 
 	ptr.video_buf_U[0] = ptr.video_buf_Y[0]
 	    + TC_MAX_V_FRAME_WIDTH * TC_MAX_V_FRAME_HEIGHT;
@@ -610,8 +624,8 @@ redisplay_frame:
 	    + (TC_MAX_V_FRAME_WIDTH * TC_MAX_V_FRAME_HEIGHT)/4;
 
 	//default pointer
-	ptr.video_buf  = ptr.internal_video_buf_0;
-	ptr.video_buf2 = ptr.internal_video_buf_1;
+	ptr.video_buf  = run_buffer[0];
+	ptr.video_buf2 = run_buffer[1];
 	ptr.free = 1;
 
 	ptr.video_size = size;
@@ -621,11 +635,11 @@ redisplay_frame:
 
 	// we disable this filter (filter_pv), because it does not make sense
 	// to be run in the preview loop
-	plugin_disable_id (this_filter);
-	process_vid_plugins (&ptr);
-	plugin_enable_id (this_filter);
-	
-	tc_memcpy (vid_buf[cache_ptr-current+1], ptr.video_buf, size);
+	tc_filter_disable(this_filter);
+	tc_filter_process((frame_list_t *)&ptr);
+	tc_filter_enable(this_filter);
+
+	ac_memcpy (vid_buf[cache_ptr-current+1], ptr.video_buf, size);
 	preview_cache_draw(0);
     }
     return;
@@ -633,32 +647,33 @@ redisplay_frame:
 }
 #endif
 
-void preview_cache_undo(void) 
+void preview_cache_undo(void)
 {
     if (!cache_enabled) return;
 
-    tc_memcpy((char *)vid_buf[cache_ptr], undo_buffer, size);
+    ac_memcpy((char *)vid_buf[cache_ptr], undo_buffer, size);
     preview_cache_draw(0);
 }
+
 void preview_cache_draw(int next) {
 
   if(!cache_enabled) return;
-  
+
   cache_ptr+=next;
-  
+
   if(next < 0) cache_ptr+=cache_num;
   while (cache_ptr<0)
       cache_ptr+=cache_num;
-  
+
   cache_ptr%=cache_num;
 
-  tc_memcpy(xv_player->display->pixels[0], (char*) vid_buf[cache_ptr], size);
+  ac_memcpy(xv_player->display->pixels[0], (char*) vid_buf[cache_ptr], size);
 
   //display video frame
   xv_display_show(xv_player->display);
-  
+
   return;
-  
+
 }
 
 void str2img(char *img, char *c, int width, int height, int char_width, int char_height, int posx, int posy, int codec)
@@ -791,10 +806,7 @@ char **char2bmp(char c) {
 
 int preview_grab_jpeg(void)
 {
-#ifdef SYS_BSD
-    const
-#endif  
-    char *error;
+    const char *error;
     char *prefix = "preview_grab-";
     vob_t *vob = tc_get_vob();
     static vob_t *mvob;
@@ -807,36 +819,36 @@ int preview_grab_jpeg(void)
     int ret = 0;
 
     if(!cache_enabled) return 1;
-    
-    if (jpeg_vhandle == NULL) { 
-	snprintf(module, sizeof(module), "%s/export_%s.so", MOD_PATH, "jpg");
+
+    if (jpeg_vhandle == NULL) {
+	tc_snprintf(module, sizeof(module), "%s/export_%s.so", MOD_PATH, "jpg");
 	jpeg_vhandle = dlopen(module, RTLD_GLOBAL| RTLD_LAZY);
 	if (!jpeg_vhandle) {
-	    tc_warn("%s", dlerror());
-	    tc_warn("(%s) loading \"%s\" failed", __FILE__, module);
+	    tc_log_error(MOD_NAME, "%s", dlerror());
+	    tc_log_error(MOD_NAME, "loading \"%s\" failed", module);
 	    return(1);
 	}
-	JPEG_export = dlsym(jpeg_vhandle, "tc_export");   
+	JPEG_export = dlsym(jpeg_vhandle, "tc_export");
 	if ((error = dlerror()) != NULL)  {
-	    tc_warn("%s", error);
+	    tc_log_error(MOD_NAME, "%s", error);
 	    return(1);
 	}
 	export_para.flag = TC_DEBUG;
 	ret = JPEG_export(TC_EXPORT_NAME, &export_para, NULL);
 
 	mvob = malloc(sizeof(vob_t));
-	tc_memcpy (mvob, vob, sizeof(vob_t));
+	ac_memcpy (mvob, vob, sizeof(vob_t));
 	mvob->video_out_file = prefix;
 
 	export_para.flag = TC_VIDEO;
 	if((ret=JPEG_export(TC_EXPORT_INIT, &export_para, mvob))==TC_EXPORT_ERROR) {
-	    tc_warn("(%s) video jpg export module error: init failed", __FILE__);
+	    tc_log_error(MOD_NAME, "video jpg export module error: init failed");
 	    return(1);
 	}
 
-	export_para.flag = TC_VIDEO;	
+	export_para.flag = TC_VIDEO;
 	if((ret=JPEG_export(TC_EXPORT_OPEN, &export_para, mvob))==TC_EXPORT_ERROR) {
-	    tc_warn("(%s) video export module error: open failed", __FILE__);
+	    tc_log_error(MOD_NAME, "video export module error: open failed");
 	    return(1);
 	}
     }
@@ -848,10 +860,10 @@ int preview_grab_jpeg(void)
     export_para.flag   = TC_VIDEO;
 
     if(JPEG_export(TC_EXPORT_ENCODE, &export_para, mvob)<0) {
-	tc_warn("(%s) error encoding jpg frame", __FILE__);
+	tc_log_warn(MOD_NAME, "error encoding jpg frame");
 	return 1;
     }
-    printf("[%s] Saved JPEG to %s%06d.jpg\n", "filter_pv", prefix, counter++);
+    tc_log_info(MOD_NAME, "Saved JPEG to %s%06d.jpg", prefix, counter++);
 
 
     return 0;
