@@ -3,112 +3,108 @@
  *
  *  Copyright (C) Tilmann Bitterberg
  *
- *  This file is part of transcode, a linux video stream processing tool
- *      
+ *  This file is part of transcode, a video stream processing tool
+ *
  *  transcode is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 2, or (at your option)
  *  any later version.
- *   
+ *
  *  transcode is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
- *   
+ *
  *  You should have received a copy of the GNU General Public License
  *  along with GNU Make; see the file COPYING.  If not, write to
- *  the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA. 
+ *  the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
  *
  */
 
-#include "config.h"
-
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-#include <sys/errno.h>
-#include <errno.h>
-#include <unistd.h>
+#include <stdint.h>
 
 #include "transcode.h"
-#include "ioaux.h"
+#include "libtc/libtc.h"
+#include "tcinfo.h"
 
-#if (HAVE_OGG && HAVE_VORBIS) 
+#include "ioaux.h"
+#include "tc.h"
+
+#if (HAVE_OGG && HAVE_VORBIS)
 #include <vorbis/vorbisfile.h>
 
-static int quiet = 0;
-static int bits = 16;
-static int endian = 0;
-static int sign = 1;
+#define TC_OGG_BUF_SIZE 8192
 
-/* ------------------------------------------------------------ 
+/* ------------------------------------------------------------
  *
  * decoder thread
  *
  * ------------------------------------------------------------*/
 
-int decode_ogg_file(int fdin, int fdout)
+static int decode_ogg_file(int fdin, int fdout, int verbose)
 {
-    FILE *in, *out=NULL;
+    FILE *in = NULL;
     OggVorbis_File vf;
-    int bs = 0;
-    char buf[8192];
-    int buflen = 8192;
+    uint8_t buf[TC_OGG_BUF_SIZE];
     unsigned int written = 0;
-    int ret;
     ogg_int64_t length = 0;
+#if 0    
     ogg_int64_t done = 0;
-    int size = 0;
-    int seekable = 0;
+#endif
+    int ret, bs = 0, size = 0, bits = 16, r = 0;
+    int seekable = 0, endian = 0, sign = 1;
+#if 0    
     int percent = 0;
+#endif
 
-    in  = fdopen (fdin,  "rb");
-    out = fdopen (fdout, "wb");
+    in  = fdopen(fdin,  "rb");
 
-    if(ov_open(in, &vf, NULL, 0) < 0) {
-        fprintf(stderr, "ERROR: Failed to open input as vorbis\n");
+    ret = ov_open(in, &vf, NULL, 0);
+    if (ret < 0) {
+        tc_log_error(__FILE__, "Failed to open input as vorbis");
         fclose(in);
-        fclose(out);
         return 1;
     }
 
-    if(ov_seekable(&vf)) {
+    if (ov_seekable(&vf)) {
         seekable = 1;
         length = ov_pcm_total(&vf, 0);
         size = bits/8 * ov_info(&vf, 0)->channels;
     }
 
-    while((ret = ov_read(&vf, buf, buflen, endian, bits/8, sign, &bs)) != 0) {
-        if(bs != 0) {
-            fprintf(stderr, "Only one logical bitstream currently supported\n");
+    while ((r = ov_read(&vf, buf, TC_OGG_BUF_SIZE,
+                        endian, bits/8, sign, &bs)) != 0) {
+        if (bs != 0) {
+            tc_log_error(__FILE__, "Only one logical bitstream currently supported");
             break;
         }
 
-        if(ret < 0 && !quiet) {
-            fprintf(stderr, "Warning: hole in data\n");
+        if (r < 0 && verbose) {
+            tc_log_warn(__FILE__, "hole in data");
             continue;
         }
 
-        if(fwrite(buf, 1, ret, out) != ret) {
-            fprintf(stderr, "Error writing to file: %s\n", strerror(errno));
+        ret = tc_pwrite(fdout, buf, r);
+        if (ret != r) {
+            tc_log_perror(__FILE__, "Error writing to file");
             ov_clear(&vf);
-            fclose(out);
             return 1;
         }
 
         written += ret;
-        if(!quiet && seekable) {
+#if 0        
+        if(verbose && seekable) {
             done += ret/size;
             if((double)done/(double)length * 200. > (double)percent) {
                 percent = (double)done/(double)length *200;
-                fprintf(stderr, "\r\t[%5.1f%%]", (double)percent/2.);
+                fprintf(stderr, "\r[%5.1f%%]", (double)percent/2.);
             }
         }
+#endif
     }
 
     ov_clear(&vf);
 
-    fclose(out);
     return 0;
 }
 #endif // HAVE_OGG
@@ -116,20 +112,29 @@ int decode_ogg_file(int fdin, int fdout)
 
 void decode_ogg(decode_t *decode)
 {
-  
-#if (HAVE_OGG && HAVE_VORBIS) 
-  
-  quiet = decode->verbose;
-  //bits = decode->a_bits;
-  decode_ogg_file(decode->fd_in, decode->fd_out);
 
+#if (HAVE_OGG && HAVE_VORBIS)
+
+  decode_ogg_file(decode->fd_in, decode->fd_out, decode->verbose);
   import_exit(0);
 
 #else
-  
-  fprintf(stderr, "(%s) no support for VORBIS decoding configured - exit.\n", __FILE__);
+
+  tc_log_error(__FILE__, "no support for VORBIS decoding configured - exit.");
   import_exit(1);
 
 #endif
-  
+
 }
+
+/*************************************************************************/
+
+/*
+ * Local variables:
+ *   c-file-style: "stroustrup"
+ *   c-file-offsets: ((case-label . *) (statement-case-intro . *))
+ *   indent-tabs-mode: nil
+ * End:
+ *
+ * vim: expandtab shiftwidth=4:
+ */
