@@ -24,7 +24,7 @@
  */
 
 #define MOD_NAME    "import_imlist.so"
-#define MOD_VERSION "v0.1.1 (2007-08-14)"
+#define MOD_VERSION "v0.1.1 (2007-08-04)"
 #define MOD_CODEC   "(video) RGB"
 
 #ifdef HAVE_CONFIG_H
@@ -45,32 +45,33 @@
 #undef PACKAGE_TARNAME
 #undef PACKAGE_VERSION
 
-#include "transcode.h"
-
 #include <stdlib.h>
 #include <stdio.h>
 
+#include "src/transcode.h"
+
 static int verbose_flag = TC_QUIET;
 static int capability_flag = TC_CAP_RGB|TC_CAP_VID;
 
 #define MOD_PRE imlist
 #include "import_def.h"
 
-static int width = 0, height = 0;
-static FILE *fd = NULL;
-static MagickWand *wand = NULL;
 
 static int TCHandleMagickError(MagickWand *wand)
 {
     ExceptionType severity;
     const char *description = MagickGetException(wand, &severity);
 
-    fprintf(stderr, "[%s] %s\n", MOD_NAME, description);
+    tc_log_error(MOD_NAME, "%s", description);
 
     MagickRelinquishMemory((void*)description);
     return TC_IMPORT_ERROR;
 }
 
+static int width = 0, height = 0;
+static FILE *fd = NULL;
+static MagickWand *wand = NULL;
+
 /* ------------------------------------------------------------
  *
  * open stream
@@ -89,6 +90,14 @@ MOD_open
         width  = vob->im_v_width;
         height = vob->im_v_height;
 
+        tc_log_warn(MOD_NAME,
+                    "This module is DEPRECATED.");
+        tc_log_warn(MOD_NAME,
+                    "Please consider to use the multi input mode"
+                    " (--multi_input) with import_im module.");
+        tc_log_warn(MOD_NAME,
+                    "(e.g.) transcode --multi_input -x im ...");
+
         fd = fopen(vob->video_in_file, "r");
         if (fd == NULL) {
             return TC_IMPORT_ERROR;
@@ -98,7 +107,7 @@ MOD_open
         wand = NewMagickWand();
 
         if (wand == NULL) {
-            fprintf(stderr, "[%s] cannot create magick wand\n", MOD_NAME);
+            tc_log_error(MOD_NAME, "cannot create magick wand");
             return TC_IMPORT_ERROR;
         }
 
@@ -125,17 +134,12 @@ MOD_decode
     }
 
     if (param->flag == TC_VIDEO) {
-        char *pc = NULL;
-
         // read a filename from the list
         if (fgets(filename, PATH_MAX, fd) == NULL) {
             return TC_IMPORT_ERROR;
         }
         filename[PATH_MAX] = '\0'; /* enforce */
-        pc = strrchr(filename, '\n'); /* chop trialing '\n' */
-        if (pc) {
-            *pc = '\0'; /* should always succeed */
-        }
+        tc_strstrip(filename);
 
         ClearMagickWand(wand);
         /* 
