@@ -21,11 +21,13 @@
  *
  */
 
-#include "config.h"
+#include "transcode.h"
+#include "libtc/libtc.h"
 
 #ifdef HAVE_LIBXML2
 
-#include "ioaux.h"
+#include "tcinfo.h"
+#include "magic.h"
 #include "tc.h"
 #include "ioxml.h"
 
@@ -101,7 +103,7 @@ audiovideo_limit_t f_det_time(char *p_options)
     }
     else
     {
-        fprintf(stderr,"Invalid parameter %s force default",p_options);
+        tc_log_warn(__FILE__,"Invalid parameter %s force default",p_options);
         s_limit.s_time=-1;
         s_limit.s_frame=0;
     }
@@ -112,12 +114,12 @@ audiovideo_limit_t f_det_time(char *p_options)
 void f_free_tree(audiovideo_t *p_node)
 {
     if (p_node) {
-        audiovideo_t *p_temp,*p_temp1;
-        for (p_temp=p_node->p_next;p_temp !=NULL;)  //first element is static
-        {
-            p_temp1=p_temp->p_next;
+        audiovideo_t *p_temp = NULL , *p_temp1 = NULL;
+        for (p_temp=p_node->p_next;p_temp !=NULL;)  {
+            //first element is static
+            p_temp1 = p_temp->p_next;
             free(p_temp);
-            p_temp=p_temp1; 
+            p_temp=p_temp1;
         }
     }
 }
@@ -131,18 +133,17 @@ int f_parse_tree(xmlNodePtr p_node,audiovideo_t *p_audiovideo)
     static int s_video_codec=TC_CODEC_UNKNOWN,s_audio_codec=TC_CODEC_UNKNOWN;
 
     s_rc=0;
-    if (p_node != NULL) 
+    if (p_node != NULL)
     {
-            if (xmlStrcmp(p_node->name, (const xmlChar*)"smil") == 0) 
+            if (xmlStrcmp(p_node->name, (const xmlChar*)"smil") == 0)
         {
                 if(f_parse_tree(p_node->xmlChildrenNode,p_audiovideo))
                 s_rc=1;
             }
-            else if (xmlStrcmp(p_node->name, (const xmlChar*)"seq") == 0) 
+            else if (xmlStrcmp(p_node->name, (const xmlChar*)"seq") == 0)
         {
             s_type=AUDIO_VIDEO_UNKNOWN;
-            p_temp=(audiovideo_t *)malloc(sizeof(audiovideo_t));
-            memset(p_temp,'\0',sizeof(audiovideo_t));
+            p_temp=tc_zalloc(sizeof(audiovideo_t));
             p_temp->s_end_a_time=-1;
             p_temp->s_end_v_time=-1;
             p_temp->s_start_a_time=-1;
@@ -176,13 +177,12 @@ int f_parse_tree(xmlNodePtr p_node,audiovideo_t *p_audiovideo)
                 s_rc=1;
                 if(f_parse_tree(p_node->next,p_temp))       //eventually go to the next seq item
                 s_rc=1;
-            } 
+            }
         else if (xmlStrcmp(p_node->name, (const xmlChar*)"video") == 0)
         {
             if (s_type!=AUDIO_VIDEO_UNKNOWN)
             {
-                p_temp=(audiovideo_t *)malloc(sizeof(audiovideo_t));
-                memset(p_temp,'\0',sizeof(audiovideo_t));
+                p_temp=tc_zalloc(sizeof(audiovideo_t));
                 p_temp->s_end_a_time=-1;
                 p_temp->s_end_v_time=-1;
                 p_temp->s_start_a_time=-1;
@@ -209,7 +209,7 @@ int f_parse_tree(xmlNodePtr p_node,audiovideo_t *p_audiovideo)
                 if(p_audiovideo != NULL)
                     p_audiovideo->p_next=p_temp;
                 p_audiovideo=p_temp;
-            }   
+            }
             s_type=VIDEO_ITEM;  //set origin to video
                 if(f_parse_tree((xmlNodePtr)p_node->properties,p_audiovideo)) //visit the properties
                 s_rc=1;
@@ -222,8 +222,7 @@ int f_parse_tree(xmlNodePtr p_node,audiovideo_t *p_audiovideo)
         {
             if (s_type!=AUDIO_VIDEO_UNKNOWN)
             {
-                p_temp=(audiovideo_t *)malloc(sizeof(audiovideo_t));
-                memset(p_temp,'\0',sizeof(audiovideo_t));
+                p_temp=tc_zalloc(sizeof(audiovideo_t));
                 p_temp->s_end_a_time=-1;
                 p_temp->s_end_v_time=-1;
                 p_temp->s_start_a_time=-1;
@@ -250,7 +249,7 @@ int f_parse_tree(xmlNodePtr p_node,audiovideo_t *p_audiovideo)
                 if(p_audiovideo != NULL)
                     p_audiovideo->p_next=p_temp;
                 p_audiovideo=p_temp;
-            }   
+            }
             s_type=AUDIO_ITEM;  //set origin to audio
                 if(f_parse_tree((xmlNodePtr)p_node->properties,p_audiovideo)) //visit the properties
                 s_rc=1;
@@ -268,7 +267,7 @@ int f_parse_tree(xmlNodePtr p_node,audiovideo_t *p_audiovideo)
                 if(f_parse_tree(p_node->next,p_audiovideo))     //eventually go to the next audio/video item
                 s_rc=1;
             }
-        else if (xmlStrcmp(p_node->name, (const xmlChar*)"src") == 0) 
+        else if (xmlStrcmp(p_node->name, (const xmlChar*)"src") == 0)
         {
             if (s_type==AUDIO_ITEM)
             {
@@ -281,7 +280,7 @@ int f_parse_tree(xmlNodePtr p_node,audiovideo_t *p_audiovideo)
                 if(f_parse_tree(p_node->next,p_audiovideo))     //goto to begin and end of clip
                 s_rc=1;
             }
-        else if (xmlStrcmp(p_node->name, (const xmlChar*)"clipBegin") == 0) 
+        else if (xmlStrcmp(p_node->name, (const xmlChar*)"clipBegin") == 0)
         {
             s_limit=f_det_time((char *)p_node->xmlChildrenNode->content);
             if (s_type==AUDIO_ITEM)
@@ -299,7 +298,7 @@ int f_parse_tree(xmlNodePtr p_node,audiovideo_t *p_audiovideo)
                 if(f_parse_tree(p_node->next,p_audiovideo))     //goto the next param.
                 s_rc=1;
             }
-        else if (xmlStrcmp(p_node->name, (const xmlChar*)"clipEnd") == 0) 
+        else if (xmlStrcmp(p_node->name, (const xmlChar*)"clipEnd") == 0)
         {
             s_limit=f_det_time((char *)p_node->xmlChildrenNode->content);
             if (s_type==AUDIO_ITEM)
@@ -317,21 +316,21 @@ int f_parse_tree(xmlNodePtr p_node,audiovideo_t *p_audiovideo)
                 if(f_parse_tree(p_node->next,p_audiovideo))     //goto the next param.
                 s_rc=1;
             }
-        else if (xmlStrcmp(p_node->name, (const xmlChar*)"name") == 0) 
+        else if (xmlStrcmp(p_node->name, (const xmlChar*)"name") == 0)
         {
-            if (xmlStrcmp((char *)p_node->xmlChildrenNode->content, (const xmlChar*)"in-video-module") == 0) 
+            if (xmlStrcmp((char *)p_node->xmlChildrenNode->content, (const xmlChar*)"in-video-module") == 0)
                 s_param=IN_VIDEO_MAGIC;
-            else if (xmlStrcmp((char *)p_node->xmlChildrenNode->content, (const xmlChar*)"in-audio-module") == 0) 
+            else if (xmlStrcmp((char *)p_node->xmlChildrenNode->content, (const xmlChar*)"in-audio-module") == 0)
                 s_param=IN_AUDIO_MAGIC;
-            else if (xmlStrcmp((char *)p_node->xmlChildrenNode->content, (const xmlChar*)"in-video-codec") == 0) 
+            else if (xmlStrcmp((char *)p_node->xmlChildrenNode->content, (const xmlChar*)"in-video-codec") == 0)
                 s_param=IN_VIDEO_CODEC;
-            else if (xmlStrcmp((char *)p_node->xmlChildrenNode->content, (const xmlChar*)"in-audio-codec") == 0) 
+            else if (xmlStrcmp((char *)p_node->xmlChildrenNode->content, (const xmlChar*)"in-audio-codec") == 0)
                 s_param=IN_AUDIO_CODEC;
-            else if (xmlStrcmp((char *)p_node->xmlChildrenNode->content, (const xmlChar*)"target-height") == 0) 
+            else if (xmlStrcmp((char *)p_node->xmlChildrenNode->content, (const xmlChar*)"target-height") == 0)
                 s_param=OUT_VIDEO_HEIGHT;
-            else if (xmlStrcmp((char *)p_node->xmlChildrenNode->content, (const xmlChar*)"target-width") == 0) 
+            else if (xmlStrcmp((char *)p_node->xmlChildrenNode->content, (const xmlChar*)"target-width") == 0)
                 s_param=OUT_VIDEO_WIDTH;
-            else if (xmlStrcmp((char *)p_node->xmlChildrenNode->content, (const xmlChar*)"resize-filter") == 0) 
+            else if (xmlStrcmp((char *)p_node->xmlChildrenNode->content, (const xmlChar*)"resize-filter") == 0)
                 s_param=OUT_VIDEO_RES_FILTER;
             else
                 s_param=UNSUPPORTED_PARAM;
@@ -339,18 +338,18 @@ int f_parse_tree(xmlNodePtr p_node,audiovideo_t *p_audiovideo)
                 if(f_parse_tree(p_node->next,p_audiovideo))     //goto the next param.
                 s_rc=1;
             }
-        else if (xmlStrcmp(p_node->name, (const xmlChar*)"value") == 0) 
+        else if (xmlStrcmp(p_node->name, (const xmlChar*)"value") == 0)
         {
             if ((s_type==AUDIO_ITEM) && ((s_param==IN_VIDEO_CODEC)||(s_param==IN_VIDEO_MAGIC)||(s_param==OUT_VIDEO_HEIGHT)||(s_param==OUT_VIDEO_WIDTH)))
             {
                 if (s_param==OUT_VIDEO_HEIGHT)
-                    fprintf(stderr,"(%s) The target-height parameter cannot be used in audio item, %s skipped.\n",__FILE__,(char *)p_node->xmlChildrenNode->content);
+                    tc_log_warn(__FILE__,"The target-height parameter cannot be used in audio item, %s skipped.",(char *)p_node->xmlChildrenNode->content);
                 else if (s_param==OUT_VIDEO_WIDTH)
-                    fprintf(stderr,"(%s) The target-width parameter cannot be used in audio item, %s skipped.\n",__FILE__,(char *)p_node->xmlChildrenNode->content);
+                    tc_log_warn(__FILE__,"The target-width parameter cannot be used in audio item, %s skipped.",(char *)p_node->xmlChildrenNode->content);
                 else if (s_param==IN_VIDEO_MAGIC)
-                    fprintf(stderr,"(%s) The in-video-module parameter cannot be used in audio item, %s skipped.\n",__FILE__,(char *)p_node->xmlChildrenNode->content);
+                    tc_log_warn(__FILE__,"The in-video-module parameter cannot be used in audio item, %s skipped.",(char *)p_node->xmlChildrenNode->content);
                 else if (s_param==IN_VIDEO_CODEC)
-                    fprintf(stderr,"(%s) The in-video-codec parameter cannot be used in audio item, %s skipped.\n",__FILE__,(char *)p_node->xmlChildrenNode->content);
+                    tc_log_warn(__FILE__,"The in-video-codec parameter cannot be used in audio item, %s skipped.",(char *)p_node->xmlChildrenNode->content);
                 s_rc=1;
             }
             else
@@ -373,11 +372,9 @@ int f_parse_tree(xmlNodePtr p_node,audiovideo_t *p_audiovideo)
                             p_audiovideo->s_v_magic=TC_MAGIC_AVI;
                         else if (xmlStrcmp((char *)p_node->xmlChildrenNode->content, (const xmlChar*)"mov") == 0)
                             p_audiovideo->s_v_magic=TC_MAGIC_AVI;
-                        else if (xmlStrcmp((char *)p_node->xmlChildrenNode->content, (const xmlChar*)"af6") == 0)
-                            p_audiovideo->s_v_magic=TC_MAGIC_AF6;
                         else
                         {
-                            fprintf(stderr,"(%s) The in-video-magic %s parameter isn't yet supported.\n",__FILE__,(char *)p_node->xmlChildrenNode->content);
+                            tc_log_warn(__FILE__,"The in-video-magic %s parameter isn't yet supported.",(char *)p_node->xmlChildrenNode->content);
                             s_rc=1;
                         }
                     break;
@@ -388,35 +385,35 @@ int f_parse_tree(xmlNodePtr p_node,audiovideo_t *p_audiovideo)
                             p_audiovideo->s_a_magic=TC_MAGIC_AVI;
                         else if (xmlStrcmp((char *)p_node->xmlChildrenNode->content, (const xmlChar*)"mov") == 0)
                             p_audiovideo->s_a_magic=TC_MAGIC_AVI;
-                        else if (xmlStrcmp((char *)p_node->xmlChildrenNode->content, (const xmlChar*)"af6") == 0)
-                            p_audiovideo->s_a_magic=TC_MAGIC_AF6;
                         else
                         {
-                            fprintf(stderr,"(%s) The in-audio-magic %s parameter isn't yet supported.\n",__FILE__,(char *)p_node->xmlChildrenNode->content);
+                            tc_log_warn(__FILE__,"The in-audio-magic %s parameter isn't yet supported.",(char *)p_node->xmlChildrenNode->content);
                             s_rc=1;
                         }
                     break;
                     case IN_VIDEO_CODEC:
                         if (xmlStrcmp((char *)p_node->xmlChildrenNode->content, (const xmlChar*)"rgb") == 0)
-                            p_audiovideo->s_v_codec=CODEC_RGB;  
+                            p_audiovideo->s_v_codec=CODEC_RGB;
                         else if (xmlStrcmp((char *)p_node->xmlChildrenNode->content, (const xmlChar*)"yuv2") == 0)
-                            p_audiovideo->s_v_codec=CODEC_YUV;  
+                            p_audiovideo->s_v_codec=CODEC_YUV;
+                        else if (xmlStrcmp((char *)p_node->xmlChildrenNode->content, (const xmlChar*)"yuv420p") == 0)
+                            p_audiovideo->s_v_codec=CODEC_YUV;
                         else if (xmlStrcmp((char *)p_node->xmlChildrenNode->content, (const xmlChar*)"yv12") == 0)
-                            p_audiovideo->s_v_codec=CODEC_YUV;  
+                            p_audiovideo->s_v_codec=CODEC_YUV;
                         else if (xmlStrcmp((char *)p_node->xmlChildrenNode->content, (const xmlChar*)"yuy2") == 0)
-                            p_audiovideo->s_v_codec=CODEC_YUY2; 
+                            p_audiovideo->s_v_codec=CODEC_YUY2;
                         else if (xmlStrcmp((char *)p_node->xmlChildrenNode->content, (const xmlChar*)"raw") == 0)
-                            p_audiovideo->s_v_codec=CODEC_RAW;  
+                            p_audiovideo->s_v_codec=CODEC_RAW;
                         else
                         {
-                            fprintf(stderr,"(%s) The in-video-codec %s parameter isn't yet supported.\n",__FILE__,(char *)p_node->xmlChildrenNode->content);
+                            tc_log_warn(__FILE__,"The in-video-codec %s parameter isn't yet supported.",(char *)p_node->xmlChildrenNode->content);
                             s_rc=1;
                         }
                         if (s_video_codec == TC_CODEC_UNKNOWN)
                             s_video_codec=p_audiovideo->s_v_codec;
                         else if (s_video_codec != p_audiovideo->s_v_codec)
                         {
-                            fprintf(stderr,"(%s) The XML file must contain the same video codec.\n",__FILE__);
+                            tc_log_warn(__FILE__,"The XML file must contain the same video codec.");
                             s_rc=1;
                         }
                     break;
@@ -425,20 +422,20 @@ int f_parse_tree(xmlNodePtr p_node,audiovideo_t *p_audiovideo)
                             p_audiovideo->s_a_codec=CODEC_PCM;
                         else
                         {
-                            fprintf(stderr,"(%s) The in-audio-codec %s parameter isn't yet supported.\n",__FILE__,(char *)p_node->xmlChildrenNode->content);
+                            tc_log_warn(__FILE__,"The in-audio-codec %s parameter isn't yet supported.",(char *)p_node->xmlChildrenNode->content);
                             s_rc=1;
                         }
                         if (s_audio_codec == TC_CODEC_UNKNOWN)
                             s_audio_codec=p_audiovideo->s_a_codec;
                         else if (s_audio_codec != p_audiovideo->s_a_codec)
                         {
-                            fprintf(stderr,"(%s) The XML file must contain the same audio codec.\n",__FILE__);
+                            tc_log_warn(__FILE__,"The XML file must contain the same audio codec.");
                             s_rc=1;
                         }
                     break;
 
                     case UNSUPPORTED_PARAM:
-                        fprintf(stderr,"(%s) The %s parameter isn't yet supported.\n",__FILE__,(char *)p_node->xmlChildrenNode->content);
+                        tc_log_warn(__FILE__,"The %s parameter isn't yet supported.",(char *)p_node->xmlChildrenNode->content);
                         s_rc=1;
                     break;
                 }
@@ -453,23 +450,23 @@ int f_parse_tree(xmlNodePtr p_node,audiovideo_t *p_audiovideo)
 
 void f_delete_unused_node(xmlNodePtr p_node)
 {
-    while (p_node != NULL) 
+    while (p_node != NULL)
     {
             xmlNodePtr p_kill_node = NULL;
 
             f_delete_unused_node(p_node->xmlChildrenNode);
-            if (xmlStrcmp(p_node->name, (const xmlChar*)"smil") == 0) 
+            if (xmlStrcmp(p_node->name, (const xmlChar*)"smil") == 0)
         {
                     //leave it in the tree
             }
-            else if (xmlStrcmp(p_node->name, (const xmlChar*)"seq") == 0) 
+            else if (xmlStrcmp(p_node->name, (const xmlChar*)"seq") == 0)
         {
-                if (p_node->xmlChildrenNode == NULL) 
+                if (p_node->xmlChildrenNode == NULL)
             {
                 //This node don't have any video sections so i can kill it
                         p_kill_node = p_node;
                     }
-            } 
+            }
         else if ((xmlStrcmp(p_node->name, (const xmlChar*)"param") == 0) ||(xmlStrcmp(p_node->name, (const xmlChar*)"video") == 0) || (xmlStrcmp(p_node->name, (const xmlChar*)"audio") == 0))
         {
                     //leave it in the tree
@@ -481,7 +478,7 @@ void f_delete_unused_node(xmlNodePtr p_node)
         }
             p_node = p_node->next;
 
-            if (p_kill_node != NULL) 
+            if (p_kill_node != NULL)
         {
             //kill the node from the tree
                 xmlUnlinkNode(p_kill_node);
@@ -514,10 +511,10 @@ int f_complete_tree(audiovideo_t *p_audiovideo)
             {
                 if ((s_video_codec!=TC_CODEC_UNKNOWN) && (p_audiovideo->s_v_codec != s_video_codec))
                 {
-                    fprintf(stderr,"(%s) The file must contain the same video codec (found 0x%lx but 0x%x is already define)", __FILE__,p_audiovideo->s_v_codec,s_video_codec);
+                    tc_log_error(__FILE__,"The file must contain the same video codec (found 0x%lx but 0x%x is already defined)",p_audiovideo->s_v_codec,s_video_codec);
                     return(1);
                 }
-                s_video_codec=p_audiovideo->s_v_codec;  
+                s_video_codec=p_audiovideo->s_v_codec;
             }
         }
         if (p_temp->p_nome_audio != NULL)
@@ -536,10 +533,10 @@ int f_complete_tree(audiovideo_t *p_audiovideo)
             {
                 if ((s_audio_codec!=TC_CODEC_UNKNOWN) && (p_audiovideo->s_a_codec != s_audio_codec))
                 {
-                    fprintf(stderr,"(%s) The file must contain the same audio codec (found 0x%lx but 0x%x is already define)", __FILE__,p_audiovideo->s_a_codec,s_audio_codec);
+                    tc_log_error(__FILE__,"The file must contain the same audio codec (found 0x%lx but 0x%x is already defined)",p_audiovideo->s_a_codec,s_audio_codec);
                     return(1);
                 }
-                s_audio_codec=p_audiovideo->s_a_codec;  
+                s_audio_codec=p_audiovideo->s_a_codec;
             }
         }
         else
@@ -555,52 +552,52 @@ int f_complete_tree(audiovideo_t *p_audiovideo)
     for (p_temp=p_audiovideo->p_next;p_temp != NULL;p_temp=p_temp->p_next) //initialize all unset codec
     {
         if (p_temp->p_nome_video != NULL)
-            p_audiovideo->s_v_codec=s_video_codec;  
+            p_audiovideo->s_v_codec=s_video_codec;
         if (p_temp->p_nome_audio != NULL)
-            p_audiovideo->s_a_codec=s_audio_codec;  
+            p_audiovideo->s_a_codec=s_audio_codec;
     }
     return(0);
 
 }
-int f_manage_input_xml(char *p_name,int s_type,audiovideo_t *p_audiovideo)
+int f_manage_input_xml(const char *p_name,int s_type,audiovideo_t *p_audiovideo)
 {
-        static xmlDocPtr p_doc;
-        xmlNodePtr p_node;
-        xmlNsPtr ns;
+    static xmlDocPtr p_doc;
+    xmlNodePtr p_node;
+    xmlNsPtr ns;
 
-        if (s_type)     //read the file from p_name
+    if (s_type)     //read the file from p_name
+    {
+        p_doc = xmlParseFile(p_name);
+        p_node = xmlDocGetRootElement(p_doc);
+        if (p_node == NULL)
         {
-            p_doc=xmlParseFile(p_name);
-            p_node = xmlDocGetRootElement(p_doc);
-            if (p_node == NULL)
-            {
-                xmlFreeDoc(p_doc);
-                fprintf(stderr,"Invalid file format\n");
-                return(-1);
-            }
-            ns = xmlSearchNsByHref(p_doc, p_node, (const xmlChar *) "http://www.w3.org/2001/SMIL20/Language");
-            if (ns == NULL)
-            {
-                xmlFreeDoc(p_doc);
-                fprintf(stderr,"Invalid Namespace \n");
-                return(-1);
-            }
-            ns = xmlSearchNs(p_doc, p_node, (const xmlChar *) "smil2");
-            if (ns == NULL)
-            {
-                xmlFreeDoc(p_doc);
-               fprintf(stderr,"Invalid Namespace \n");
-                return(-1);
-            }
-            if (xmlStrcmp(p_node->name, (const xmlChar *) "smil"))
-            {
-               xmlFreeDoc(p_doc);
-               fprintf(stderr,"Invalid Namespace \n");
-                return(-1);
-            }
-            f_delete_unused_node(p_node);
-            memset(p_audiovideo,'\0',sizeof(audiovideo_t));
-            if(f_parse_tree(p_node,p_audiovideo))
+            xmlFreeDoc(p_doc);
+            tc_log_error(__FILE__,"Invalid file format");
+            return(-1);
+        }
+        ns = xmlSearchNsByHref(p_doc, p_node, (const xmlChar *) "http://www.w3.org/2001/SMIL20/Language");
+        if (ns == NULL)
+        {
+            xmlFreeDoc(p_doc);
+            tc_log_error(__FILE__,"Invalid Namespace");
+            return(-1);
+        }
+        ns = xmlSearchNs(p_doc, p_node, (const xmlChar *) "smil2");
+        if (ns == NULL)
+        {
+            xmlFreeDoc(p_doc);
+            tc_log_error(__FILE__,"Invalid Namespace");
+            return(-1);
+        }
+        if (xmlStrcmp(p_node->name, (const xmlChar *) "smil"))
+        {
+            xmlFreeDoc(p_doc);
+            tc_log_error(__FILE__,"Invalid Namespace");
+            return(-1);
+        }
+        f_delete_unused_node(p_node);
+        memset(p_audiovideo,'\0',sizeof(audiovideo_t));
+        if(f_parse_tree(p_node,p_audiovideo))
             return(1);
         if (f_complete_tree(p_audiovideo))
             return(1);
