@@ -113,7 +113,7 @@ void version(void)
     if (tcversion++)
         return;
     fprintf(stderr, "%s v%s (C) 2001-2003 Thomas Oestreich,"
-                              " 2003-2009 Transcode Team\n",
+                              " 2003-2010 Transcode Team\n",
                               PACKAGE, VERSION);
 }
 
@@ -968,6 +968,7 @@ static vob_t *new_vob(void)
     vob->hori_resize2        = 0;
     vob->sync                = 0;
     vob->sync_ms             = 0;
+    vob->sync_samples        = 0;
     vob->dvd_title           = 1;
     vob->dvd_chapter1        = 1;
     vob->dvd_chapter2        = -1;
@@ -2038,7 +2039,8 @@ int main(int argc, char *argv[])
             tc_log_info(PACKAGE,
                         "V: %-16s | %03dx%03d  %4.2f:1 (%s)",
                         "zoom",
-                        vob->ex_v_width, vob->ex_v_height, asr, zoom_filter);
+                        vob->ex_v_width, vob->ex_v_height, asr,
+                        tcv_zoom_filter_to_string(vob->zoom_filter));
     }
 
     // -Y
@@ -2255,7 +2257,7 @@ int main(int argc, char *argv[])
         if (vob->vob_chunk < 0 || vob->vob_chunk < 0)
             tc_error("invalid parameter for option -W");
     } else {
-        if (vob->vob_chunk < 0 || vob->vob_chunk > vob->vob_chunk_max)
+        if (vob->vob_chunk < 0 || vob->vob_chunk > vob->vob_chunk_max + 1)
             tc_error("invalid parameter for option -W");
     }
 
